@@ -60,16 +60,18 @@
 
 using std::vector;
 
-#include "filesys.h"
 #include "error_numbers.h"
-#include "util.h"
-#include "str_util.h"
+#include "filesys.h"
 #include "parse.h"
 #include "shmem.h"
+#include "str_util.h"
+#include "util.h"
+
 #include "client_msgs.h"
 #include "client_state.h"
 #include "file_names.h"
 #include "proc_control.h"
+#include "result.h"
 #include "sandbox.h"
 
 #include "app.h"
@@ -96,12 +98,12 @@ bool ACTIVE_TASK_SET::poll() {
         ACTIVE_TASK* atp = active_tasks[i];
         if (atp->task_state() == PROCESS_ABORT_PENDING) {
             if (gstate.now > atp->abort_time + ABORT_TIMEOUT) {
-                atp->kill_task();
+                atp->kill_task(false);
             }
         }
         if (atp->task_state() == PROCESS_QUIT_PENDING) {
             if (gstate.now > atp->quit_time + QUIT_TIMEOUT) {
-                atp->kill_task();
+                atp->kill_task(true);
             }
         }
     }
@@ -175,13 +177,14 @@ int ACTIVE_TASK::request_abort() {
     return 0;
 }
 
-static void kill_app_process(int pid) {
 #ifdef _WIN32
+static void kill_app_process(int pid, bool will_restart) {
     HANDLE h = OpenProcess(READ_CONTROL | PROCESS_TERMINATE, false, pid);
     if (h == NULL) return;
-    TerminateProcess(h, 1);
+    TerminateProcess(h, will_restart?0:EXIT_ABORTED_BY_CLIENT);
     CloseHandle(h);
 #else
+static void kill_app_process(int pid, bool) {
 #ifdef SANDBOX
     kill_via_switcher(pid);
 #endif
@@ -189,15 +192,15 @@ static void kill_app_process(int pid) {
 #endif
 }
 
-static inline void kill_processes(vector<int> pids) {
+static inline void kill_processes(vector<int> pids, bool will_restart) {
     for (unsigned int i=0; i<pids.size(); i++) {
-        kill_app_process(pids[i]);
+        kill_app_process(pids[i], will_restart);
     }
 }
 
 // Kill the task (and descendants) by OS-specific means.
 //
-int ACTIVE_TASK::kill_task() {
+int ACTIVE_TASK::kill_task(bool will_restart) {
     vector<int>pids;
 #ifdef _WIN32
     // On Win, in protected mode we won't be able to get
@@ -206,7 +209,7 @@ int ACTIVE_TASK::kill_task() {
     // using the handle we got when we created it.
     //
     if (g_use_sandbox) {
-        TerminateProcess(process_handle, 1);
+        TerminateProcess(process_handle, will_restart?0:EXIT_ABORTED_BY_CLIENT);
         return 0;
     }
 #endif
@@ -215,7 +218,7 @@ int ACTIVE_TASK::kill_task() {
     for (unsigned int i=0; i<other_pids.size(); i++) {
         pids.push_back(other_pids[i]);
     }
-    kill_processes(pids);
+    kill_processes(pids, will_restart);
     return 0;
 }
 
@@ -338,17 +341,22 @@ void ACTIVE_TASK::handle_temporary_exit(
 //
 #ifdef _WIN32
 void ACTIVE_TASK::handle_exited_app(unsigned long exit_code) {
-#else
-void ACTIVE_TASK::handle_exited_app(int stat) {
-#endif
-    bool will_restart = false;
-
     if (log_flags.task_debug) {
         msg_printf(result->project, MSG_INFO,
-            "[task] Process for %s exited",
-            result->name
+            "[task] Process for %s exited, exit code %lu, task state %d",
+            result->name, exit_code, task_state()
         );
     }
+#else
+void ACTIVE_TASK::handle_exited_app(int stat) {
+    if (log_flags.task_debug) {
+        msg_printf(result->project, MSG_INFO,
+            "[task] Process for %s exited, status %d, task state %d",
+            result->name, stat, task_state()
+        );
+    }
+#endif
+    bool will_restart = false;
 
     get_app_status_msg();
     get_trickle_up_msg();
@@ -361,10 +369,10 @@ void ACTIVE_TASK::handle_exited_app(int stat) {
     //
     if (task_state() == PROCESS_ABORT_PENDING) {
         set_task_state(PROCESS_ABORTED, "handle_exited_app");
-        kill_processes(descendants);
+        kill_processes(descendants, false);
     } else if (task_state() == PROCESS_QUIT_PENDING) {
         set_task_state(PROCESS_UNINITIALIZED, "handle_exited_app");
-        kill_processes(descendants);
+        kill_processes(descendants, true);
         will_restart = true;
     } else {
 #ifdef _WIN32
@@ -488,7 +496,7 @@ void ACTIVE_TASK::handle_exited_app(int stat) {
                 );
             }
         } else {
-            result->exit_status = -1;
+            result->exit_status = EXIT_UNKNOWN;
             set_task_state(PROCESS_EXIT_UNKNOWN, "handle_exited_app");
             gstate.report_result_error(*result, "process exit, unknown");
             msg_printf(result->project, MSG_INTERNAL_ERROR,
@@ -619,7 +627,7 @@ void ACTIVE_TASK_SET::process_control_poll() {
                     "Restarting %s - message timeout", atp->result->name
                 );
             }
-            atp->kill_task();
+            atp->kill_task(true);
         } else {
             atp->process_control_queue.msg_queue_poll(
                 atp->app_client_shm.shm->process_control_request
@@ -707,7 +715,7 @@ bool ACTIVE_TASK::check_max_disk_exceeded() {
                 "Aborting task %s: exceeded disk limit: %.2fMB > %.2fMB\n",
                 result->name, disk_usage/MEGA, max_disk_usage/MEGA
             );
-            abort_task(ERR_RSC_LIMIT_EXCEEDED, "Maximum disk usage exceeded");
+            abort_task(EXIT_DISK_LIMIT_EXCEEDED, "Maximum disk usage exceeded");
             return true;
         }
     }
@@ -745,7 +753,7 @@ bool ACTIVE_TASK_SET::check_rsc_limits_exceeded() {
                 atp->result->wup->rsc_fpops_bound/1e9,
                 atp->result->avp->flops/1e9
             );
-            atp->abort_task(ERR_RSC_LIMIT_EXCEEDED, "Maximum elapsed time exceeded");
+            atp->abort_task(EXIT_TIME_LIMIT_EXCEEDED, "Maximum elapsed time exceeded");
             did_anything = true;
             continue;
         }
@@ -755,7 +763,7 @@ bool ACTIVE_TASK_SET::check_rsc_limits_exceeded() {
                 atp->result->name,
                 atp->procinfo.working_set_size_smoothed/MEGA, max_ram/MEGA
             );
-            atp->abort_task(ERR_RSC_LIMIT_EXCEEDED, "Maximum memory exceeded");
+            atp->abort_task(EXIT_MEM_LIMIT_EXCEEDED, "Maximum memory exceeded");
             did_anything = true;
             continue;
         }
@@ -779,6 +787,7 @@ bool ACTIVE_TASK_SET::check_rsc_limits_exceeded() {
 // kill it by OS-specific mechanism (e.g. KILL signal).
 // This is done when app has exceeded CPU, disk, or mem limits,
 // or when the user has requested it.
+// The task won't be restarted.
 //
 int ACTIVE_TASK::abort_task(int exit_status, const char* msg) {
     if (task_state() == PROCESS_EXECUTING || task_state() == PROCESS_SUSPENDED) {
@@ -1084,7 +1093,7 @@ void ACTIVE_TASK_SET::kill_tasks(PROJECT* proj) {
         atp = active_tasks[i];
         if (proj && atp->wup->project != proj) continue;
         if (!atp->process_exists()) continue;
-        atp->kill_task();
+        atp->kill_task(true);
     }
 }
 
