@@ -81,6 +81,7 @@ using std::string;
 #include "client_msgs.h"
 #include "client_state.h"
 #include "file_names.h"
+#include "result.h"
 #include "sandbox.h"
 #include "unix_util.h"
 
@@ -384,7 +385,7 @@ int ACTIVE_TASK::setup_file(
             }
             if (fip->nbytes > ASYNC_FILE_THRESHOLD) {
                 ASYNC_COPY* ac = new ASYNC_COPY;
-                retval = ac->init(this, file_path, link_path);
+                retval = ac->init(this, fip, file_path, link_path);
                 if (retval) return retval;
                 return ERR_IN_PROGRESS;
             } else {
@@ -396,10 +397,9 @@ int ACTIVE_TASK::setup_file(
                     );
                     return retval;
                 }
+                retval = fip->set_permissions(link_path);
+                if (retval) return retval;
             }
-#ifdef SANDBOX
-            return set_to_project_group(link_path);
-#endif
         }
         return 0;
     }
@@ -614,7 +614,7 @@ int ACTIVE_TASK::start() {
     link_user_files();
         // don't check retval here
 
-    // make sure temporary exit file isn't there
+    // remove temporary exit file from last run
     //
     sprintf(file_path, "%s/%s", slot_dir, TEMPORARY_EXIT_FILE);
     delete_project_owned_file(file_path, true);
