@@ -56,6 +56,8 @@
 #include "hostinfo_network.h"
 #include "http_curl.h"
 #include "network.h"
+#include "project.h"
+#include "result.h"
 #include "sandbox.h"
 #include "shmem.h"
 
@@ -610,6 +612,10 @@ int CLIENT_STATE::init() {
     //
     check_too_large_jobs();
 
+    // initialize project priorities (for the GUI, in case we're suspended)
+    //
+    project_priority_init(false);
+
     initialized = true;
     return 0;
 }
@@ -1199,7 +1205,7 @@ bool CLIENT_STATE::abort_unstarted_late_jobs() {
             "Aborting task %s; not started and deadline has passed",
             rp->name
         );
-        rp->abort_inactive(ERR_UNSTARTED_LATE);
+        rp->abort_inactive(EXIT_UNSTARTED_LATE);
         action = true;
     }
     return action;
@@ -1750,6 +1756,7 @@ int CLIENT_STATE::reset_project(PROJECT* project, bool detaching) {
             i--;
         }
     }
+    project->last_upload_start = 0;
 
     // if we're in the middle of a scheduler op to the project, abort it
     //
@@ -2029,9 +2036,9 @@ void CLIENT_STATE::start_abort_sequence() {
         if (rp->computing_done()) continue;
         ACTIVE_TASK* atp = lookup_active_task_by_result(rp);
         if (atp) {
-            atp->abort_task(ERR_ABORTED_ON_EXIT, "aborting on client exit");
+            atp->abort_task(EXIT_CLIENT_EXITING, "aborting on client exit");
         } else {
-            rp->abort_inactive(ERR_ABORTED_ON_EXIT);
+            rp->abort_inactive(EXIT_CLIENT_EXITING);
         }
     }
     for (i=0; i<projects.size(); i++) {
