@@ -197,30 +197,30 @@ CL_INFO         __clGetDeviceInfo = NULL;
 void* opencl_lib = NULL;
 
 cl_int (*__clGetPlatformIDs)(
-    cl_uint    /* num_entries */,
-    cl_platform_id * /* platforms */,
-    cl_uint *        /* num_platforms */
+    cl_uint,         // num_entries,
+    cl_platform_id*, // platforms
+    cl_uint *        // num_platforms
 );
 cl_int (*__clGetPlatformInfo)(
-    cl_platform_id   /* platform */,
-    cl_platform_info /* param_name */,
-    size_t           /* param_value_size */,
-    void *           /* param_value */,
-    size_t *         /* param_value_size_ret */
+    cl_platform_id,  // platform
+    cl_platform_info, // param_name
+    size_t,          // param_value_size
+    void*,           // param_value
+    size_t*          // param_value_size_ret
 );
 cl_int (*__clGetDeviceIDs)(
-    cl_platform_id   /* platform */,
-    cl_device_type   /* device_type */,
-    cl_uint          /* num_entries */,
-    cl_device_id *   /* devices */,
-    cl_uint *        /* num_devices */
+    cl_platform_id,  // platform
+    cl_device_type,  // device_type
+    cl_uint,         // num_entries
+    cl_device_id*,   // devices
+    cl_uint*         // num_devices
 );
 cl_int (*__clGetDeviceInfo)(
-    cl_device_id    /* device */,
-    cl_device_info  /* param_name */,
-    size_t          /* param_value_size */,
-    void *          /* param_value */,
-    size_t *        /* param_value_size_ret */
+    cl_device_id,    // device
+    cl_device_info,  // param_name
+    size_t,          // param_value_size
+    void*,           // param_value
+    size_t*          // param_value_size_ret
 );
 
 #endif
@@ -670,6 +670,7 @@ cl_int COPROCS::get_opencl_info(
 // the OpenCL info into the CAL or CUDA data for the "best" CAL or CUDA GPU.
 // This assumes that, for each GPU, we have previously correlated its CAL 
 // or CUDA device_num with its opencl_device_index.
+//
 void COPROC::merge_opencl(
     vector<OPENCL_DEVICE_PROP> &opencls, 
     vector<int>& ignore_dev
@@ -703,6 +704,7 @@ void COPROC::merge_opencl(
 }
 
 // This is called for ATI GPUs without CAL or NVIDIA GPUs without CUDA
+//
 void COPROC::find_best_opencls(
     bool use_all,
     vector<OPENCL_DEVICE_PROP> &opencls, 
@@ -812,17 +814,17 @@ enum CUdevice_attribute_enum {
 #ifdef _WIN32
 typedef int (__stdcall *CUDA_GDC)(int *count);
 typedef int (__stdcall *CUDA_GDV)(int* version);
-typedef int (__stdcall *CUDA_GDI)(int);
+typedef int (__stdcall *CUDA_GDI)(unsigned int);
 typedef int (__stdcall *CUDA_GDG)(int*, int);
 typedef int (__stdcall *CUDA_GDA)(int*, int, int);
 typedef int (__stdcall *CUDA_GDN)(char*, int, int);
-typedef int (__stdcall *CUDA_GDM)(unsigned int*, int);
+typedef int (__stdcall *CUDA_GDM)(size_t*, int);
 typedef int (__stdcall *CUDA_GDCC)(int*, int*, int);
 typedef int (__stdcall *CUDA_CC)(void**, unsigned int, unsigned int);
 typedef int (__stdcall *CUDA_CD)(void*);
-typedef int (__stdcall *CUDA_MA)(unsigned int*, unsigned int);
+typedef int (__stdcall *CUDA_MA)(unsigned int*, size_t);
 typedef int (__stdcall *CUDA_MF)(unsigned int);
-typedef int (__stdcall *CUDA_MGI)(unsigned int*, unsigned int*);
+typedef int (__stdcall *CUDA_MGI)(size_t*, size_t*);
 
 CUDA_GDC __cuDeviceGetCount = NULL;
 CUDA_GDV __cuDriverGetVersion = NULL;
@@ -839,19 +841,19 @@ CUDA_MF __cuMemFree = NULL;
 CUDA_MGI __cuMemGetInfo = NULL;
 #else
 void* cudalib;
-int (*__cuInit)(int);
+int (*__cuInit)(unsigned int);
 int (*__cuDeviceGetCount)(int*);
 int (*__cuDriverGetVersion)(int*);
 int (*__cuDeviceGet)(int*, int);
 int (*__cuDeviceGetAttribute)(int*, int, int);
 int (*__cuDeviceGetName)(char*, int, int);
-int (*__cuDeviceTotalMem)(unsigned int*, int);
+int (*__cuDeviceTotalMem)(size_t*, int);
 int (*__cuDeviceComputeCapability)(int*, int*, int);
 int (*__cuCtxCreate)(void**, unsigned int, unsigned int);
 int (*__cuCtxDestroy)(void*);
-int (*__cuMemAlloc)(unsigned int*, unsigned int);
+int (*__cuMemAlloc)(unsigned int*, size_t);
 int (*__cuMemFree)(unsigned int);
-int (*__cuMemGetInfo)(unsigned int*, unsigned int*);
+int (*__cuMemGetInfo)(size_t*, size_t*);
 #endif
 
 // NVIDIA interfaces are documented here:
@@ -907,17 +909,17 @@ void COPROC_NVIDIA::get(
     }
     __cuDeviceGetCount = (int(*)(int*)) dlsym(cudalib, "cuDeviceGetCount");
     __cuDriverGetVersion = (int(*)(int*)) dlsym( cudalib, "cuDriverGetVersion" );
-    __cuInit = (int(*)(int)) dlsym( cudalib, "cuInit" );
+    __cuInit = (int(*)(unsigned int)) dlsym( cudalib, "cuInit" );
     __cuDeviceGet = (int(*)(int*, int)) dlsym( cudalib, "cuDeviceGet" );
     __cuDeviceGetAttribute = (int(*)(int*, int, int)) dlsym( cudalib, "cuDeviceGetAttribute" );
     __cuDeviceGetName = (int(*)(char*, int, int)) dlsym( cudalib, "cuDeviceGetName" );
-    __cuDeviceTotalMem = (int(*)(unsigned int*, int)) dlsym( cudalib, "cuDeviceTotalMem" );
+    __cuDeviceTotalMem = (int(*)(size_t*, int)) dlsym( cudalib, "cuDeviceTotalMem" );
     __cuDeviceComputeCapability = (int(*)(int*, int*, int)) dlsym( cudalib, "cuDeviceComputeCapability" );
     __cuCtxCreate = (int(*)(void**, unsigned int, unsigned int)) dlsym( cudalib, "cuCtxCreate" );
     __cuCtxDestroy = (int(*)(void*)) dlsym( cudalib, "cuCtxDestroy" );
-    __cuMemAlloc = (int(*)(unsigned int*, unsigned int)) dlsym( cudalib, "cuMemAlloc" );
+    __cuMemAlloc = (int(*)(unsigned int*, size_t)) dlsym( cudalib, "cuMemAlloc" );
     __cuMemFree = (int(*)(unsigned int)) dlsym( cudalib, "cuMemFree" );
-    __cuMemGetInfo = (int(*)(unsigned int*, unsigned int*)) dlsym( cudalib, "cuMemGetInfo" );
+    __cuMemGetInfo = (int(*)(size_t*, size_t*)) dlsym( cudalib, "cuMemGetInfo" );
 #endif
 
     if (!__cuDriverGetVersion) {
@@ -994,6 +996,7 @@ void COPROC_NVIDIA::get(
 
     int j;
     unsigned int i;
+    size_t global_mem;
     COPROC_NVIDIA cc;
     string s;
     for (j=0; j<cuda_ndevs; j++) {
@@ -1020,7 +1023,8 @@ if (j == 0) {
             return;
         }
         (*__cuDeviceComputeCapability)(&cc.prop.major, &cc.prop.minor, device);
-        (*__cuDeviceTotalMem)(&cc.prop.totalGlobalMem, device);
+        (*__cuDeviceTotalMem)(&global_mem, device);
+        cc.prop.totalGlobalMem = (double) global_mem;
         (*__cuDeviceGetAttribute)(&cc.prop.sharedMemPerBlock, CU_DEVICE_ATTRIBUTE_SHARED_MEMORY_PER_BLOCK, device);
         (*__cuDeviceGetAttribute)(&cc.prop.regsPerBlock, CU_DEVICE_ATTRIBUTE_REGISTERS_PER_BLOCK, device);
         (*__cuDeviceGetAttribute)(&cc.prop.warpSize, CU_DEVICE_ATTRIBUTE_WARP_SIZE, device);
@@ -1106,7 +1110,7 @@ void COPROC_NVIDIA::fake(
    display_driver_version = driver_version;
    cuda_version = 2020;
    strcpy(prop.name, "Fake NVIDIA GPU");
-   prop.totalGlobalMem = (unsigned int)ram;
+   prop.totalGlobalMem = ram;
    prop.sharedMemPerBlock = 100;
    prop.regsPerBlock = 8;
    prop.warpSize = 10;
@@ -1134,11 +1138,11 @@ void COPROC_NVIDIA::fake(
 //
 void COPROC_NVIDIA::get_available_ram() {
     int retval;
-    unsigned int memfree, memtotal;
-	int device;
+    size_t memfree, memtotal;
+    int device;
     void* ctx;
     
-    available_ram = prop.dtotalGlobalMem;
+    available_ram = prop.totalGlobalMem;
     retval = (*__cuDeviceGet)(&device, device_num);
     if (retval) {
         if (log_flags.coproc_debug) {
@@ -1263,7 +1267,7 @@ int (*__calDeviceClose)(CALdevice);
 void COPROC_ATI::get(
     bool use_all,
     vector<string>& warnings,
-	vector<int>& ignore_devs
+    vector<int>& ignore_devs
 ) {
     CALuint numDevices, cal_major, cal_minor, cal_imp;
     char buf[256];
@@ -1622,22 +1626,21 @@ void COPROCS::get_ati_mem_size_from_opengl() {
             
             CGOpenGLDisplayMask myMask = 1 << i;
             CGDirectDisplayID displayID = CGOpenGLDisplayMaskToDisplayID(myMask);
-            theErr2 = CGLQueryRendererInfo (myMask, 
-                                      &info, 
-                                      &numRenderers);
-
+            theErr2 = CGLQueryRendererInfo(myMask, &info, &numRenderers); 
             if ((displayID != kCGNullDirectDisplay) && (theErr2 == kCGLNoError)) {
                 // Get the I/O Kit service port for the display
                 io_registry_entry_t dspPort = CGDisplayIOServicePort(displayID);
                 for (j = 0; j < numRenderers; j++) {
-                  // find accelerated renderer (assume only one)
+                    // find accelerated renderer (assume only one)
                     CGLDescribeRenderer (info, j, kCGLRPAcceleratedCompute, &rv); 
                     if (true == rv) { // if openCL-capable
                         // what is the renderer ID
                         CGLDescribeRenderer (info, j, kCGLRPRendererID, &rendererIDs[i]);
-                        modelName[i] = (CFDataRef)IORegistryEntrySearchCFProperty(dspPort,
+                        modelName[i] = (CFDataRef)IORegistryEntrySearchCFProperty(
+                            dspPort,
                             kIOServicePlane, CFSTR("model"), kCFAllocatorDefault,
-                            kIORegistryIterateRecursively | kIORegistryIterateParents);
+                            kIORegistryIterateRecursively | kIORegistryIterateParents
+                        );
                     }
                     if (modelName[i] != NULL) break;
                 }
@@ -1645,9 +1648,7 @@ void COPROCS::get_ati_mem_size_from_opengl() {
         }
     }   // End if (log_flags.coproc_debug) {
 
-    theErr2 = CGLQueryRendererInfo (0xffffffff, 
-                                  &info, 
-                                  &numRenderers);
+    theErr2 = CGLQueryRendererInfo( 0xffffffff, &info, &numRenderers);
     if (theErr2 == kCGLNoError) {
         CGLDescribeRenderer (info, 0, kCGLRPRendererCount, &numRenderers);
         for (i = 0; i < numRenderers; i++) {
@@ -1658,17 +1659,17 @@ void COPROCS::get_ati_mem_size_from_opengl() {
             CGLDescribeRenderer (info, i, kCGLRPAcceleratedCompute, &rv); 
             if (true == rv) { // if openCL-capable
                 // what is the renderer ID
-                CGLDescribeRenderer (info, i, kCGLRPRendererID,
-                                     &rendererID);
+                CGLDescribeRenderer (info, i, kCGLRPRendererID, &rendererID);
                // what is the VRAM?
-                CGLDescribeRenderer (info, i, kCGLRPVideoMemory,
-                                     &deviceVRAM);
+                CGLDescribeRenderer (info, i, kCGLRPVideoMemory, &deviceVRAM);
 
                 // build context and context specific info
-                CGLPixelFormatAttribute attribs[] = { kCGLPFARendererID,
-                                                    (CGLPixelFormatAttribute)rendererID, 
-                                                    kCGLPFAAllowOfflineRenderers,
-                                                    (CGLPixelFormatAttribute)0 };
+                CGLPixelFormatAttribute attribs[] = {
+                    kCGLPFARendererID,
+                    (CGLPixelFormatAttribute)rendererID, 
+                    kCGLPFAAllowOfflineRenderers,
+                    (CGLPixelFormatAttribute)0
+                };
                 CGLPixelFormatObj pixelFormat = NULL;
                 GLint numPixelFormats = 0;
                 CGLContextObj cglContext;
@@ -1711,8 +1712,8 @@ void COPROCS::get_ati_mem_size_from_opengl() {
                                     }
                                     if (strcmp(iokit_name, opencl_name)) {
                                         msg_printf(0, MSG_INFO,
-                                        "[coproc] get_ati_mem_size_from_opengl model name mismatch: %s vs %s\n", 
-                                        ati_opencls[ati_gpu_index].name, (char *)CFDataGetBytePtr(modelName[j])
+                                            "[coproc] get_ati_mem_size_from_opengl model name mismatch: %s vs %s\n", 
+                                            ati_opencls[ati_gpu_index].name, (char *)CFDataGetBytePtr(modelName[j])
                                         );
                                     }
                                 } else {
@@ -1729,8 +1730,8 @@ void COPROCS::get_ati_mem_size_from_opengl() {
                                     if ((strRend == NULL) || 
                                         (!strstr(iokit_name, opencl_name))) {
                                         msg_printf(0, MSG_INFO,
-                                        "[coproc] get_ati_mem_size_from_opengl model name to renderer mismatch: %s vs %s\n", 
-                                        strRend, ati_opencls[ati_gpu_index].name
+                                            "[coproc] get_ati_mem_size_from_opengl model name to renderer mismatch: %s vs %s\n", 
+                                            strRend, ati_opencls[ati_gpu_index].name
                                         );
                                     }
                                 }
@@ -1743,16 +1744,16 @@ void COPROCS::get_ati_mem_size_from_opengl() {
                     } else {
                         if (log_flags.coproc_debug) {
                             msg_printf(0, MSG_INFO,
-                            "[coproc] get_ati_mem_size_from_opengl failed to create context\n"
+                                "[coproc] get_ati_mem_size_from_opengl failed to create context\n"
                             );
                         }
                     }
                 } else {
-                        if (log_flags.coproc_debug) {
-                            msg_printf(0, MSG_INFO,
+                    if (log_flags.coproc_debug) {
+                        msg_printf(0, MSG_INFO,
                             "[coproc] get_ati_mem_size_from_opengl failed to create PixelFormat\n"
-                            );
-                        }
+                        );
+                    }
                 }
             }       // End if kCGLRPAcceleratedCompute attribute
         }   // End loop: for (i = 0; i < numRenderers; i++)
