@@ -151,9 +151,6 @@ double cpu_peak_flops() {
     return gstate.ncpus * gstate.host_info.p_fpops;
 }
 
-double total_peak_flops() {
-    return gpu_peak_flops() + cpu_peak_flops();
-}
 void print_project_results(FILE* f) {
     for (unsigned int i=0; i<gstate.projects.size(); i++) {
         PROJECT* p = gstate.projects[i];
@@ -505,7 +502,7 @@ bool CLIENT_STATE::scheduler_rpc_poll() {
         }
 #endif
     
-        p = find_project_with_overdue_results();
+        p = find_project_with_overdue_results(false);
         if (p) {
             //printf("doing RPC to %s to report results\n", p->project_name);
             work_fetch.compute_work_request(p);
@@ -525,7 +522,7 @@ bool CLIENT_STATE::scheduler_rpc_poll() {
         must_check_work_fetch = false;
         last_work_fetch_time = now;
 
-        p = work_fetch.choose_project();
+        p = work_fetch.choose_project(true);
 
         if (p) {
             action = simulate_rpc(p);
@@ -978,7 +975,7 @@ void html_end() {
 void set_initial_rec() {
     unsigned int i;
     double sum=0;
-    double x = total_peak_flops();
+    double x = cpu_peak_flops() + gpu_peak_flops();
     for (i=0; i<gstate.projects.size(); i++) {
         sum += gstate.projects[i]->resource_share;
     }
