@@ -33,11 +33,9 @@
 #include "MainDocument.h"
 #include "wx/valgen.h"
 #include "wx/valtext.h"
-#include "hyperlink.h"
 #include "ValidateEmailAddress.h"
-#include "BOINCWizards.h"
 #include "BOINCBaseWizard.h"
-#include "WizardAttachProject.h"
+#include "WizardAttach.h"
 #include "ProjectInfoPage.h"
 #include "AccountManagerInfoPage.h"
 #include "AccountInfoPage.h"
@@ -137,8 +135,8 @@ void CAccountInfoPage::CreateControls()
     m_pCookieDetectionFailedStaticCtrl->Hide();
     itemBoxSizer57->Add(m_pCookieDetectionFailedStaticCtrl, 0, wxALIGN_LEFT|wxALL, 5);
 
-    m_pCookieDetectionFailedCtrl = new wxHyperLink;
-    m_pCookieDetectionFailedCtrl->Create( itemWizardPage56, ID_ACCOUNTCOOKIEDETECTIONFAILEDCTRL, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0 );
+    m_pCookieDetectionFailedCtrl = new wxHyperlinkCtrl;
+    m_pCookieDetectionFailedCtrl->Create( itemWizardPage56, ID_ACCOUNTCOOKIEDETECTIONFAILEDCTRL, wxT(" "), wxT(" "), wxDefaultPosition, wxDefaultSize, wxNO_BORDER | wxHL_ALIGN_LEFT | wxHL_CONTEXTMENU );
     m_pCookieDetectionFailedCtrl->Hide();
     itemBoxSizer57->Add(m_pCookieDetectionFailedCtrl, 0, wxALIGN_LEFT|wxALL, 5);
 
@@ -176,6 +174,14 @@ void CAccountInfoPage::CreateControls()
     m_pAccountEmailAddressCtrl->Create( itemWizardPage56, ID_ACCOUNTEMAILADDRESSCTRL, wxEmptyString, wxDefaultPosition, wxSize(200, 22), 0 );
     itemFlexGridSizer64->Add(m_pAccountEmailAddressCtrl, 0, wxEXPAND|wxALIGN_CENTER_VERTICAL|wxALL, 5);
 
+    m_pAccountUsernameStaticCtrl = new wxStaticText;
+    m_pAccountUsernameStaticCtrl->Create( itemWizardPage56, ID_ACCOUNTUSERNAMESTATICCTRL, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0 );
+    itemFlexGridSizer64->Add(m_pAccountUsernameStaticCtrl, 0, wxALIGN_RIGHT|wxALIGN_CENTER_VERTICAL|wxALL, 5);
+
+    m_pAccountUsernameCtrl = new wxTextCtrl;
+    m_pAccountUsernameCtrl->Create( itemWizardPage56, ID_ACCOUNTUSERNAMECTRL, wxEmptyString, wxDefaultPosition, wxSize(200, 22), 0 );
+    itemFlexGridSizer64->Add(m_pAccountUsernameCtrl, 0, wxEXPAND|wxALIGN_CENTER_VERTICAL|wxALL, 5);
+
     m_pAccountPasswordStaticCtrl = new wxStaticText;
     m_pAccountPasswordStaticCtrl->Create( itemWizardPage56, ID_ACCOUNTPASSWORDSTATICCTRL, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0 );
     itemFlexGridSizer64->Add(m_pAccountPasswordStaticCtrl, 0, wxALIGN_RIGHT|wxALIGN_CENTER_VERTICAL|wxALL, 5);
@@ -203,13 +209,15 @@ void CAccountInfoPage::CreateControls()
     m_pAccountManagerLinkLabelStaticCtrl->Create( itemWizardPage56, ID_ACCOUNTLINKLABELSTATICCTRL, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0 );
     itemBoxSizer57->Add(m_pAccountManagerLinkLabelStaticCtrl, 0, wxGROW|wxALIGN_CENTER_VERTICAL|wxALL, 5);
 
-    m_pAccountForgotPasswordCtrl = new wxHyperLink;
-    m_pAccountForgotPasswordCtrl->Create( itemWizardPage56, ID_ACCOUNTFORGOTPASSWORDCTRL, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0 );
+    m_pAccountForgotPasswordCtrl = new wxHyperlinkCtrl;
+    m_pAccountForgotPasswordCtrl->Create( itemWizardPage56, ID_ACCOUNTFORGOTPASSWORDCTRL, wxT(" "), wxT(" "), wxDefaultPosition, wxDefaultSize, wxNO_BORDER | wxHL_ALIGN_LEFT | wxHL_CONTEXTMENU );
     itemBoxSizer57->Add(m_pAccountForgotPasswordCtrl, 0, wxGROW|wxALIGN_CENTER_VERTICAL|wxALL, 5);
 
     // Set validators
-    // m_pAccountEmailAddressCtrl is setup when the OnPageChange event is fired since
+    // m_pAccountEmailAddressCtrl/m_pAccountUsernameCtrl is setup when the OnPageChange event is fired since
     //   it can be a username or an email address.
+    m_pAccountEmailAddressCtrl->SetValidator( wxTextValidator(wxFILTER_NONE, &m_strAccountEmailAddress) );
+    m_pAccountUsernameCtrl->SetValidator( wxTextValidator(wxFILTER_NONE, &m_strAccountUsername) );
     m_pAccountPasswordCtrl->SetValidator( wxTextValidator(wxFILTER_NONE, &m_strAccountPassword) );
     m_pAccountConfirmPasswordCtrl->SetValidator( wxTextValidator(wxFILTER_NONE, &m_strAccountConfirmPassword) );
     
@@ -219,19 +227,19 @@ void CAccountInfoPage::CreateControls()
     HIObjectRef   theObject = (HIObjectRef)HIViewGetSuperview(buttonView);
     HIObjectSetAccessibilityIgnored(theObject, true);
 #endif
-////@end CAccountInfoPage content construction
+    ////@end CAccountInfoPage content construction
 
 }
- 
+
 /*!
  * Gets the previous page.
  */
- 
+
 wxWizardPageEx* CAccountInfoPage::GetPrev() const
 {
     return PAGE_TRANSITION_BACK;
 }
- 
+
 /*!
  * Gets the next page.
  */
@@ -289,16 +297,15 @@ wxIcon CAccountInfoPage::GetIconResource( const wxString& WXUNUSED(name) )
 void CAccountInfoPage::OnPageChanged( wxWizardExEvent& event ) {
     if (event.GetDirection() == false) return;
 
-    PROJECT_CONFIG&        pc = ((CBOINCBaseWizard*)GetParent())->project_config;
-    CSkinAdvanced*         pSkinAdvanced = wxGetApp().GetSkinManager()->GetAdvanced();
-    CSkinWizardATAM*       pSkinWizardATAM = wxGetApp().GetSkinManager()->GetWizards()->GetWizardATAM();
-    CWizardAttachProject*  pWAP = ((CWizardAttachProject*)GetParent());
-    wxString               strBaseConfigLocation = wxString(wxT("/Wizards"));
-    wxConfigBase*          pConfig = wxConfigBase::Get(FALSE);
+    CWizardAttach*   pWA = ((CWizardAttach*)GetParent());
+    CSkinAdvanced*   pSkinAdvanced = wxGetApp().GetSkinManager()->GetAdvanced();
+    CSkinWizardATAM* pSkinWizardATAM = wxGetApp().GetSkinManager()->GetWizards()->GetWizardATAM();
+    PROJECT_CONFIG&  pc = pWA->project_config;
+    wxString         strBaseConfigLocation = wxString(wxT("/Wizards"));
+    wxConfigBase*    pConfig = wxConfigBase::Get(FALSE);
  
     wxASSERT(pSkinAdvanced);
     wxASSERT(pSkinWizardATAM);
-    wxASSERT(pWAP);
     wxASSERT(m_pTitleStaticCtrl);
     wxASSERT(m_pCookieDetectionFailedStaticCtrl);
     wxASSERT(m_pCookieDetectionFailedCtrl);
@@ -308,6 +315,8 @@ void CAccountInfoPage::OnPageChanged( wxWizardExEvent& event ) {
     wxASSERT(m_pAccountUseExistingCtrl);
     wxASSERT(m_pAccountEmailAddressStaticCtrl);
     wxASSERT(m_pAccountEmailAddressCtrl);
+    wxASSERT(m_pAccountUsernameStaticCtrl);
+    wxASSERT(m_pAccountUsernameCtrl);
     wxASSERT(m_pAccountPasswordStaticCtrl);
     wxASSERT(m_pAccountPasswordCtrl);
     wxASSERT(m_pAccountConfirmPasswordStaticCtrl);
@@ -320,9 +329,10 @@ void CAccountInfoPage::OnPageChanged( wxWizardExEvent& event ) {
 
 
     // We are entering this page, so reterieve the previously used email
-    // address.
+    // address and/or username.
     pConfig->SetPath(strBaseConfigLocation);
     m_strAccountEmailAddress = pConfig->Read(wxT("DefaultEmailAddress"));
+    m_strAccountUsername = pConfig->Read(wxT("DefaultUsername"));
 
     // Setup the desired controls and default values.
     static bool bRunOnce = true;
@@ -335,7 +345,7 @@ void CAccountInfoPage::OnPageChanged( wxWizardExEvent& event ) {
     }
 
     if (IS_ACCOUNTMANAGERWIZARD()) {
-        if (!(pWAP->m_bCookieRequired && !pWAP->m_bCredentialsDetected)) {
+        if (!(pWA->m_bCookieRequired && !pWA->m_bCredentialsDetected)) {
             m_pCookieDetectionFailedStaticCtrl->Hide();
             m_pCookieDetectionFailedCtrl->Hide();
         } else {
@@ -352,7 +362,7 @@ void CAccountInfoPage::OnPageChanged( wxWizardExEvent& event ) {
         m_pAccountConfirmPasswordCtrl->Hide();
         m_pAccountPasswordRequirmentsStaticCtrl->Hide();
 
-        if (pWAP->m_bCookieRequired && !pWAP->m_bCredentialsDetected) {
+        if (pWA->m_bCookieRequired && !pWA->m_bCredentialsDetected) {
             m_pAccountManagerLinkLabelStaticCtrl->Hide();
             m_pAccountForgotPasswordCtrl->Hide();
         }
@@ -383,7 +393,7 @@ void CAccountInfoPage::OnPageChanged( wxWizardExEvent& event ) {
 			);
 		} else if (pc.account_creation_disabled) {
 			m_pAccountQuestionStaticCtrl->SetLabel(
-				_("This project is not currently accepting new accounts.\nYou can attach only if you already have an account.")
+				_("This project is not currently accepting new accounts.\nYou can add it only if you already have an account.")
 			);
 		} else {
 			m_pAccountQuestionStaticCtrl->SetLabel(
@@ -397,15 +407,15 @@ void CAccountInfoPage::OnPageChanged( wxWizardExEvent& event ) {
             _("&Yes, existing user")
         );
     } else {
-        if (pWAP->m_bCookieRequired && !pWAP->m_bCredentialsDetected) {
+        if (pWA->m_bCookieRequired && !pWA->m_bCredentialsDetected) {
             m_pCookieDetectionFailedStaticCtrl->SetLabel(
-                _("We were not able to set up your account information\nautomatically.\n\nPlease click on the 'Find logon information' link\nbelow to find out what to put in the email address and\npassword fields.")
+                _("We were not able to set up your account information\nautomatically.\n\nPlease click on the 'Find login information' link\nbelow to find out what to put in the email address and\npassword fields.")
             );
             m_pCookieDetectionFailedCtrl->SetLabel(
-                _("Find logon information")
+                _("Find login information")
             );
             m_pCookieDetectionFailedCtrl->SetURL(
-                pWAP->m_strCookieFailureURL
+                pWA->m_strCookieFailureURL
             );
         }
 
@@ -436,16 +446,16 @@ void CAccountInfoPage::OnPageChanged( wxWizardExEvent& event ) {
         );
     }
 
-    if (!((CBOINCBaseWizard*)GetParent())->project_name.IsEmpty()) {
+    if (!pWA->GetProjectName().IsEmpty()) {
         wxString strQuestion;
         strQuestion.Printf(
             _("Are you already running %s?"),
-            ((CBOINCBaseWizard*)GetParent())->project_name.c_str()
+            pWA->GetProjectName().c_str()
         );
         m_pAccountQuestionStaticCtrl->SetLabel(strQuestion);
     }
 
-    if (((CBOINCBaseWizard*)GetParent())->project_config.uses_username) {
+    if (pc.uses_username) {
         if (IS_ACCOUNTMANAGERWIZARD()) {
             if (pSkinAdvanced->IsBranded() && 
                 !pSkinWizardATAM->GetAccountInfoMessage().IsEmpty()) {
@@ -455,10 +465,22 @@ void CAccountInfoPage::OnPageChanged( wxWizardExEvent& event ) {
             }
         }
 
-        m_pAccountEmailAddressStaticCtrl->SetLabel(
+        m_pAccountEmailAddressCtrl->SetValidator( 
+            wxTextValidator(wxFILTER_NONE, &m_strAccountEmailAddress)
+        );
+        m_pAccountUsernameCtrl->SetValidator(
+            wxTextValidator(wxFILTER_ASCII, &m_strAccountUsername)
+        );
+
+        m_pAccountEmailAddressStaticCtrl->Hide();
+        m_pAccountEmailAddressCtrl->Hide();
+        m_pAccountUsernameStaticCtrl->Show();
+        m_pAccountUsernameCtrl->Show();
+
+        m_pAccountUsernameStaticCtrl->SetLabel(
             _("&Username:")
         );
-        m_pAccountEmailAddressCtrl->SetValidator( wxTextValidator(wxFILTER_ASCII, &m_strAccountEmailAddress) );
+        m_pAccountUsernameCtrl->SetValue(m_strAccountUsername);
     } else {
         if (IS_ACCOUNTMANAGERWIZARD()) {
             if (pSkinAdvanced->IsBranded() && 
@@ -469,10 +491,21 @@ void CAccountInfoPage::OnPageChanged( wxWizardExEvent& event ) {
             }
         }
 
+        m_pAccountEmailAddressCtrl->SetValidator(
+            CValidateEmailAddress(&m_strAccountEmailAddress)
+        );
+        m_pAccountUsernameCtrl->SetValidator(
+            wxTextValidator(wxFILTER_NONE, &m_strAccountUsername)
+        );
+
+        m_pAccountEmailAddressStaticCtrl->Show();
+        m_pAccountEmailAddressCtrl->Show();
+        m_pAccountUsernameStaticCtrl->Hide();
+        m_pAccountUsernameCtrl->Hide();
+
         m_pAccountEmailAddressStaticCtrl->SetLabel(
             _("&Email address:")
         );
-        m_pAccountEmailAddressCtrl->SetValidator( CValidateEmailAddress(& m_strAccountEmailAddress) );
         m_pAccountEmailAddressCtrl->SetValue(m_strAccountEmailAddress);
     }
 
@@ -488,7 +521,7 @@ void CAccountInfoPage::OnPageChanged( wxWizardExEvent& event ) {
             _("Forgot your password?")
         );
         m_pAccountForgotPasswordCtrl->SetURL(
-            wxString(pWAP->m_ProjectInfoPage->GetProjectURL() + _T("get_passwd.php"))
+            wxString(pWA->m_ProjectInfoPage->GetProjectURL() + _T("get_passwd.php"))
         );
     } else {
         m_pAccountManagerLinkLabelStaticCtrl->SetLabel(
@@ -498,12 +531,17 @@ void CAccountInfoPage::OnPageChanged( wxWizardExEvent& event ) {
             _("Account manager website")
         );
         m_pAccountForgotPasswordCtrl->SetURL(
-            wxString(pWAP->m_AccountManagerInfoPage->GetProjectURL())
+            wxString(pWA->m_AccountManagerInfoPage->GetProjectURL())
         );
     }
 
+    if (pc.uses_username) {
+        m_pAccountUsernameCtrl->SetFocus();
+    } else {
+        m_pAccountEmailAddressCtrl->SetFocus();
+    }
+
     Fit();
-    m_pAccountEmailAddressCtrl->SetFocus();
 }
   
 /*!
@@ -513,6 +551,8 @@ void CAccountInfoPage::OnPageChanged( wxWizardExEvent& event ) {
 void CAccountInfoPage::OnPageChanging( wxWizardExEvent& event ) {
     if (event.GetDirection() == false) return;
 
+    CWizardAttach*         pWA = ((CWizardAttach*)GetParent());
+    PROJECT_CONFIG&        pc = pWA->project_config;
     wxString               strTitle;
     wxString               strMessage = wxT("");
     bool                   bDisplayError = false;
@@ -524,38 +564,39 @@ void CAccountInfoPage::OnPageChanging( wxWizardExEvent& event ) {
         // use.
         pConfig->SetPath(strBaseConfigLocation);
         pConfig->Write(wxT("DefaultEmailAddress"), m_strAccountEmailAddress);
+        pConfig->Write(wxT("DefaultUsername"), m_strAccountUsername);
 
         // Construct potiental dialog title
         if (IS_ATTACHTOPROJECTWIZARD()) {
-            strTitle = _("Attach to project");
+            strTitle = _("Add project");
         } else if (IS_ACCOUNTMANAGERWIZARD() && IS_ACCOUNTMANAGERUPDATEWIZARD()) {
             strTitle = _("Update account manager");
         } else if (IS_ACCOUNTMANAGERWIZARD()) {
-            strTitle = _("Attach to account manager");
+            strTitle = _("Use account manager");
         }
  
         // Verify minimum password length
-        unsigned int iMinLength = ((CBOINCBaseWizard*)GetParent())->project_config.min_passwd_length;
-        wxString strPassword = m_pAccountPasswordCtrl->GetValue();
-        if (strPassword.Length() < iMinLength) {
-            if (IS_ATTACHTOPROJECTWIZARD()) {
-                strMessage.Printf(
-                    _("The minimum password length for this project is %d. Please enter a different password."),
-                    iMinLength
-                );
-            }
-            if (IS_ACCOUNTMANAGERWIZARD()) {
-                strMessage.Printf(
-                    _("The minimum password length for this account manager is %d. Please enter a different password."),
-                    iMinLength
-                );
-            }
+        if (!m_pAccountUseExistingCtrl->GetValue()) {
+            if (m_pAccountPasswordCtrl->GetValue().Length() < (size_t)pc.min_passwd_length) {
+                if (IS_ATTACHTOPROJECTWIZARD()) {
+                    strMessage.Printf(
+                        _("The minimum password length for this project is %d. Please enter a different password."),
+                        pc.min_passwd_length
+                    );
+                }
+                if (IS_ACCOUNTMANAGERWIZARD()) {
+                    strMessage.Printf(
+                        _("The minimum password length for this account manager is %d. Please enter a different password."),
+                        pc.min_passwd_length
+                    );
+                }
 
-            bDisplayError = true;
+                bDisplayError = true;
+            }
         }
 
+        // Verify that the password and confirmation password math.
         if (!IS_ACCOUNTMANAGERWIZARD() && m_pAccountCreateCtrl->GetValue()) {
-            // Verify that the password and confirmation password math.
             if (m_pAccountPasswordCtrl->GetValue() != m_pAccountConfirmPasswordCtrl->GetValue()) {
                 strMessage = _("The password and confirmation password do not match. Please type them again.");
                 bDisplayError = true;
@@ -587,13 +628,22 @@ void CAccountInfoPage::OnCancel( wxWizardExEvent& event ) {
  */
  
 void CAccountInfoPage::OnAccountUseExistingCtrlSelected( wxCommandEvent& WXUNUSED(event) ) {
+    CWizardAttach*         pWA = ((CWizardAttach*)GetParent());
+    PROJECT_CONFIG&        pc = pWA->project_config;
+
     m_pAccountPasswordStaticCtrl->SetLabel(
         _("&Password:")
     );
     m_pAccountConfirmPasswordStaticCtrl->Hide();
     m_pAccountConfirmPasswordCtrl->Hide();
     m_pAccountPasswordRequirmentsStaticCtrl->Hide();
-    m_pAccountEmailAddressCtrl->SetFocus();
+
+    if (pc.uses_username) {
+        m_pAccountUsernameCtrl->SetFocus();
+    } else {
+        m_pAccountEmailAddressCtrl->SetFocus();
+    }
+
     Fit();
 }
   
@@ -602,13 +652,22 @@ void CAccountInfoPage::OnAccountUseExistingCtrlSelected( wxCommandEvent& WXUNUSE
  */
  
 void CAccountInfoPage::OnAccountCreateCtrlSelected( wxCommandEvent& WXUNUSED(event) ) {
+    CWizardAttach*         pWA = ((CWizardAttach*)GetParent());
+    PROJECT_CONFIG&        pc = pWA->project_config;
+
     m_pAccountPasswordStaticCtrl->SetLabel(
         _("Choose a &password:")
     );
     m_pAccountConfirmPasswordStaticCtrl->Show();
     m_pAccountConfirmPasswordCtrl->Show();
     m_pAccountPasswordRequirmentsStaticCtrl->Show();
-    m_pAccountEmailAddressCtrl->SetFocus();
+
+    if (pc.uses_username) {
+        m_pAccountUsernameCtrl->SetFocus();
+    } else {
+        m_pAccountEmailAddressCtrl->SetFocus();
+    }
+
     Fit();
 }
 
