@@ -361,6 +361,9 @@ void CBOINCBaseFrame::OnExit(wxCommandEvent& WXUNUSED(event)) {
         SaveState();
 
         // Under wxWidgets 2.8.0, the task bar icons must be deleted for app to exit its main loop
+#ifdef __WXMAC__
+        wxGetApp().DeleteMacSystemMenu();
+#endif
         wxGetApp().DeleteTaskBarIcon();
 
         CDlgEventLog*   eventLog = wxGetApp().GetEventLog();
@@ -851,9 +854,12 @@ bool CBOINCBaseFrame::RestoreState() {
     return true;
 }
 
-
 bool CBOINCBaseFrame::Show(bool bShow) {
+    wxLogTrace(wxT("Function Start/End"), wxT("CBOINCBaseFrame::Show - Function Begin"));
+    wxLogTrace(wxT("Function Start/End"), wxT("CBOINCBaseFrame::Show - Show: '%d'"), (int)bShow);
+
     bool    retval;
+
     if (bShow) {
         wxGetApp().ShowApplication(true);
     } else {
@@ -864,23 +870,24 @@ bool CBOINCBaseFrame::Show(bool bShow) {
         }
     }
     
-    CDlgEventLog*   eventLog = wxGetApp().GetEventLog();
-    if (eventLog) {
+    CDlgEventLog* pEventLog = wxGetApp().GetEventLog();
+    if (pEventLog) {
 #ifdef __WXMAC__
         if (bShow) {
-            eventLog->Show(bShow);
+            pEventLog->Show(bShow);
         }
 #else
-        eventLog->Show(bShow);
+        pEventLog->Show(bShow);
 #endif
     }
 
     retval = wxFrame::Show(bShow);
     wxFrame::Raise();
+
+    wxLogTrace(wxT("Function Start/End"), wxT("CBOINCBaseFrame::Show - Function End"));
     return retval;
 }
 
-
 int CBOINCBaseFrame::_GetCurrentViewPage() {
     wxASSERT(false);
     return 0;
