@@ -789,6 +789,14 @@ int CBOINCGUIApp::IdleTrackerDetach() {
 
 
 void CBOINCGUIApp::OnActivateApp(wxActivateEvent& event) {
+#ifdef __WXMAC__
+    // Make sure any modal dialog (such as Attach Wizard) ends up in front.
+    if (IsModalDialogDisplayed()) {
+        event.Skip();
+        return;
+    }
+#endif
+
     if (event.GetActive()) {
         if (m_pEventLog && !m_pEventLog->IsIconized()) {
             m_pEventLog->Raise();
@@ -894,6 +902,9 @@ void CBOINCGUIApp::FireReloadSkin() {
 
 
 bool CBOINCGUIApp::SetActiveGUI(int iGUISelection, bool bShowWindow) {
+    wxLogTrace(wxT("Function Start/End"), wxT("CBOINCGUIApp::SetActiveGUI - Function Begin"));
+    wxLogTrace(wxT("Function Start/End"), wxT("CBOINCGUIApp::SetActiveGUI - GUI Selection: '%d', Show: %d'"), iGUISelection, (int)bShowWindow);
+
     CBOINCBaseFrame* pNewFrame = NULL;
     CBOINCBaseFrame* pOldFrame = m_pFrame;
     wxInt32          iTop = 0;
@@ -996,9 +1007,6 @@ bool CBOINCGUIApp::SetActiveGUI(int iGUISelection, bool bShowWindow) {
             // Delete the old one if it exists
             // Note: this has the side effect of hiding the Event Log
             if (pOldFrame) pOldFrame->Destroy();
-
-            // Show the new frame if needed (and show the Event Log if open)
-            if (pNewFrame && bShowWindow) pNewFrame->Show();
         }
     }
 
@@ -1015,6 +1023,9 @@ bool CBOINCGUIApp::SetActiveGUI(int iGUISelection, bool bShowWindow) {
         if (!m_pFrame->IsShown()) {
             m_pFrame->Show();
         }
+        if (m_pFrame->IsIconized()) {
+            m_pFrame->Maximize(false);
+        }
         m_pFrame->Raise();
 
 #ifdef __WXMSW__
@@ -1026,6 +1037,7 @@ bool CBOINCGUIApp::SetActiveGUI(int iGUISelection, bool bShowWindow) {
     m_pConfig->SetPath(wxT("/"));
     m_pConfig->Write(wxT("GUISelection"), iGUISelection);
 
+    wxLogTrace(wxT("Function Start/End"), wxT("CBOINCGUIApp::SetActiveGUI - Function End"));
     return true;
 }
 
