@@ -43,19 +43,29 @@ BEGIN_EVENT_TABLE(CDlgAdvPreferences, wxDialog)
 	EVT_COMMAND_RANGE(20000,21000,wxEVT_COMMAND_CHECKBOX_CLICKED,CDlgAdvPreferences::OnHandleCommandEvent)
 	EVT_COMMAND_RANGE(20000,21000,wxEVT_COMMAND_RADIOBUTTON_SELECTED,CDlgAdvPreferences::OnHandleCommandEvent)
 	EVT_COMMAND_RANGE(20000,21000,wxEVT_COMMAND_TEXT_UPDATED,CDlgAdvPreferences::OnHandleCommandEvent)
+    // list box
+    EVT_COMMAND(ID_LISTBOX_EXCLAPPS,wxEVT_COMMAND_LISTBOX_SELECTED,CDlgAdvPreferences::OnExclusiveAppListEvent)
 	//buttons
+	EVT_BUTTON(ID_ADDEXCLUSIVEAPPBUTTON,CDlgAdvPreferences::OnAddExclusiveApp)
+	EVT_BUTTON(ID_REMOVEEXCLUSIVEAPPBUTTON,CDlgAdvPreferences::OnRemoveExclusiveApp)
 	EVT_BUTTON(wxID_OK,CDlgAdvPreferences::OnOK)
-	EVT_BUTTON(wxID_HELP,CDlgAdvPreferences::OnHelp)
+	EVT_BUTTON(ID_HELPBOINC,CDlgAdvPreferences::OnHelp)
 	EVT_BUTTON(ID_BTN_CLEAR,CDlgAdvPreferences::OnClear)
 END_EVENT_TABLE()
 
 /* Constructor */
 CDlgAdvPreferences::CDlgAdvPreferences(wxWindow* parent) : CDlgAdvPreferencesBase(parent,ID_ANYDIALOG) {
+    CSkinAdvanced* pSkinAdvanced = wxGetApp().GetSkinManager()->GetAdvanced();
+    wxASSERT(pSkinAdvanced);
+    wxASSERT(wxDynamicCast(pSkinAdvanced, CSkinAdvanced));
+
 	m_bInInit=false;
-	m_bDataChanged=false;
+	m_bPrefsDataChanged=false;
+    m_bExclusiveAppsDataChanged=false;
 	m_arrTabPageIds.Add(ID_TABPAGE_PROC);
 	m_arrTabPageIds.Add(ID_TABPAGE_NET);
 	m_arrTabPageIds.Add(ID_TABPAGE_DISK);
+	m_arrTabPageIds.Add(ID_TABPAGE_EXCLAPPS);
 	
 	//setting tab page images (not handled by generated code)
     int iImageIndex = 0;
@@ -73,8 +83,15 @@ CDlgAdvPreferences::CDlgAdvPreferences(wxWindow* parent) : CDlgAdvPreferencesBas
 
     iImageIndex = pImageList->Add(wxBitmap(usage_xpm));
 	m_Notebook->SetPageImage(2,iImageIndex);
+    
+    iImageIndex = pImageList->Add(*pSkinAdvanced->GetApplicationSnoozeIcon());
+	m_Notebook->SetPageImage(3,iImageIndex);
+        
 	//setting warning bitmap
 	m_bmpWarning->SetBitmap(wxBitmap(warning_xpm));
+    
+    m_removeExclusiveAppButton->Disable();
+
 	// init special tooltips
 	SetSpecialTooltips();
 	//setting the validators for correct input handling
@@ -194,12 +211,12 @@ void CDlgAdvPreferences::ReadPreferenceSettings() {
     wxASSERT(wxDynamicCast(pDoc, CMainDocument));
 
 	// Get current working preferences (including any overrides) from client
-        retval = pDoc->rpc.get_global_prefs_working_struct(prefs, mask);
-        if (retval == ERR_NOT_FOUND) {
-            // Older clients don't support get_global_prefs_working_struct RPC
-            prefs = pDoc->state.global_prefs;
-            pDoc->rpc.get_global_prefs_override_struct(prefs, mask);
-        }
+    retval = pDoc->rpc.get_global_prefs_working_struct(prefs, mask);
+    if (retval == ERR_NOT_FOUND) {
+        // Older clients don't support get_global_prefs_working_struct RPC
+        prefs = pDoc->state.global_prefs;
+        pDoc->rpc.get_global_prefs_override_struct(prefs, mask);
+    }
 
 	// ######### proc usage page
 	// do work between
@@ -305,6 +322,18 @@ void CDlgAdvPreferences::ReadPreferenceSettings() {
 	*m_txtMemoryMaxOnIdle << buffer;
 	// suspend to memory
 	m_chkMemoryWhileSuspended->SetValue(prefs.leave_apps_in_memory);
+    
+    // Get cc_config.xml file flags
+    log_flags.init();
+    config.defaults();
+    retval = pDoc->rpc.get_cc_config(config, log_flags);
+    if (!retval) {
+        for (unsigned int i=0; i<config.exclusive_apps.size(); ++i) {
+            wxString appName = wxString(config.exclusive_apps[i].c_str(), wxConvUTF8);
+            m_exclusiveApsListBox->Append(appName);
+        }
+    }
+
 	m_bInInit=false;
 	//update control states
 	this->UpdateControlStates();
@@ -469,6 +498,17 @@ bool CDlgAdvPreferences::SavePreferencesSettings() {
 	//
 	prefs.leave_apps_in_memory = m_chkMemoryWhileSuspended->GetValue();
 	mask.leave_apps_in_memory=true;
+    
+    if (m_bExclusiveAppsDataChanged) {
+        wxArrayString appNames = m_exclusiveApsListBox->GetStrings();
+
+        config.exclusive_apps.clear();
+        for (unsigned int i=0; i<appNames.size(); ++i) {
+            std::string s = (const char*)appNames[i].mb_str();
+            config.exclusive_apps.push_back(s);
+        }
+    }
+
 	return true;
 }
 
@@ -701,12 +741,165 @@ bool CDlgAdvPreferences::IsValidTimeIntervalValue(const wxString& value) {
 void CDlgAdvPreferences::OnHandleCommandEvent(wxCommandEvent& ev) {
 	ev.Skip();
 	if(!m_bInInit) {
-		m_bDataChanged=true;
+		m_bPrefsDataChanged=true;
 	}
 	UpdateControlStates();
 }
 
+// ---- Exclusive Apps list box handler
+void CDlgAdvPreferences::OnExclusiveAppListEvent(wxCommandEvent& ev) {
+    wxArrayInt selections;
+    int numSelected;
+    
+	if(!m_bInInit) {
+        numSelected = m_exclusiveApsListBox->GetSelections(selections);
+        m_removeExclusiveAppButton->Enable(numSelected > 0);
+    }
+	ev.Skip();
+}
+
 // ---- command buttons handlers
+// handles Add button clicked
+void CDlgAdvPreferences::OnAddExclusiveApp(wxCommandEvent&) {
+    wxString strMachineName;
+    int i, j, n;
+    bool hostIsMac = false;
+    bool hostIsWin = false;
+    bool isDuplicate;
+    wxArrayString appNames;
+    wxChar *extension = wxT("");
+    wxString errmsg;
+    CMainDocument* pDoc = wxGetApp().GetDocument();
+
+    wxASSERT(pDoc);
+    wxASSERT(wxDynamicCast(pDoc, CMainDocument));
+
+    if (strstr(pDoc->state.host_info.os_name, "Darwin")) {
+        hostIsMac = true;
+        extension = wxT(".app");
+    } else if (strstr(pDoc->state.host_info.os_name, "Microsoft")) {
+        hostIsWin = true;
+        extension = wxT(".exe");
+    }
+    
+    pDoc->GetConnectedComputerName(strMachineName);
+    if (pDoc->IsComputerNameLocal(strMachineName)) {
+#ifdef __WXMAC__
+        wxFileDialog picker(this, _("Applications to add"), 
+                            wxT("/Applications"), wxT(""), wxT("*.app"), 
+                            wxFD_OPEN|wxFD_FILE_MUST_EXIST|wxFD_CHANGE_DIR|wxFD_MULTIPLE|wxFD_CHANGE_DIR);
+#elif defined(__WXMSW__)
+//TODO: fill in the default directory for MSW
+        wxFileDialog picker(this, _("Applications to add"), 
+                            wxT("C:/Program Files"), wxT(""), wxT("*.exe"), 
+                            wxFD_OPEN|wxFD_FILE_MUST_EXIST|wxFD_CHANGE_DIR|wxFD_MULTIPLE|wxFD_CHANGE_DIR);
+#else
+//TODO: fill in the default directory and wildcard for Linux
+        wxFileDialog picker(this, _("Applications to add"), 
+                            wxT("/"), wxT(""), wxT("*.*"), 
+                            wxFD_OPEN|wxFD_FILE_MUST_EXIST|wxFD_CHANGE_DIR|wxFD_MULTIPLE|wxFD_CHANGE_DIR);
+#endif
+        if (picker.ShowModal() != wxID_OK) return;
+        picker.GetFilenames(appNames);
+
+        for (i=appNames.Count()-1; i>=0; --i) {
+#ifdef __WXMSW__
+            // Under Windows, filename may include paths if a shortcut selected
+            wxString appNameOnly = appNames[i].AfterLast('\\');
+            appNames[i] = appNameOnly;
+#endif
+            wxString directory = picker.GetDirectory();
+            wxFileName fn(directory, appNames[i]);
+            if (!fn.IsOk() || !fn.IsFileExecutable()) {
+                errmsg.Printf(_("'%s' is not an executable application."), appNames[i].c_str());
+                wxGetApp().SafeMessageBox(errmsg, _("Add Exclusive App"),
+                            wxOK | wxICON_EXCLAMATION, this);
+                appNames.RemoveAt(i);
+                continue;
+            }
+        }
+    } else {
+        // We can't use file picker if connected to a remote computer, 
+        // so show a dialog with textedit field so user can type app name
+        wxChar path_separator = wxT('/');
+        
+        wxTextEntryDialog dlg(this, _("Name of application to add?"), _("Add exclusive app"));
+        if (hostIsMac) {
+            dlg.SetValue(extension);
+        } else if (hostIsWin) {
+            dlg.SetValue(extension);
+            path_separator = wxT('\\');
+        }
+        if (dlg.ShowModal() != wxID_OK) return;
+        
+        wxString theAppName = dlg.GetValue();
+        // Strip off path if present
+        appNames.Add(theAppName.AfterLast(path_separator));
+        
+    }
+        
+    for (i=0; i<(int)appNames.Count(); ++i) {
+        // wxFileName::IsFileExecutable() doesn't seem to work on Windows, 
+        // and we can only perform minimal validation on remote hosts, so 
+        // check filename extension on Mac and Win
+        if (hostIsMac || hostIsWin) {
+            if (!appNames[0].EndsWith(extension)) {
+                errmsg.Printf(_("Application names must end with '%s'"), extension);
+                wxGetApp().SafeMessageBox(errmsg, _("Add Exclusive App"),
+                            wxOK | wxICON_EXCLAMATION, this);
+                return;
+            }
+        }
+
+        if (hostIsMac) {
+            int suffix = appNames[i].Find('.', true);
+            if (suffix != wxNOT_FOUND) {
+                appNames[i].Truncate(suffix);
+            }
+        }
+
+        // Skip requests for duplicate entries
+        isDuplicate = false;
+        n = m_exclusiveApsListBox->GetCount();
+        for (j=0; j<n; ++j) {
+            if ((m_exclusiveApsListBox->GetString(j)).Cmp(appNames[i]) == 0) {
+                isDuplicate = true;
+                break;
+            }
+        }
+        if (isDuplicate) {
+            errmsg.Printf(_("'%s' is already in the list."), appNames[i].c_str());
+            wxGetApp().SafeMessageBox(errmsg, _("Add Exclusive App"),
+                        wxOK | wxICON_EXCLAMATION, this);
+            continue;
+        }
+        
+        m_exclusiveApsListBox->Append(appNames[i]);
+        m_bExclusiveAppsDataChanged = true;
+    }
+}
+
+static int myCompareInts(int *first, int *second) {
+    return *first - *second;
+}
+
+typedef int (*sortcomparefunc)(int*, int*);
+
+// handles Remove button clicked
+void CDlgAdvPreferences::OnRemoveExclusiveApp(wxCommandEvent& ev) {
+    wxArrayInt selections;
+    int numSelected = m_exclusiveApsListBox->GetSelections(selections);
+    
+    // The selection indices are returned in random order.
+    // We must sort them to ensure deleting the correct items.
+    selections.Sort((sortcomparefunc)&myCompareInts);
+    for (int i=numSelected-1; i>=0; --i) {
+        m_exclusiveApsListBox->Delete(selections[i]);
+        m_bExclusiveAppsDataChanged = true;
+    }
+	ev.Skip();
+}
+
 // handles OK button clicked
 void CDlgAdvPreferences::OnOK(wxCommandEvent& ev) {
     CMainDocument*    pDoc = wxGetApp().GetDocument();
@@ -721,6 +914,13 @@ void CDlgAdvPreferences::OnOK(wxCommandEvent& ev) {
 		pDoc->rpc.set_global_prefs_override_struct(prefs,mask);		
 		pDoc->rpc.read_global_prefs_override();
 	}
+    
+    if (m_bExclusiveAppsDataChanged) {
+        int retval = pDoc->rpc.set_cc_config(config, log_flags);
+        if (!retval) {
+            pDoc->rpc.read_cc_config();
+        }
+    }
 	ev.Skip();
 }
 
@@ -758,7 +958,8 @@ void CDlgAdvPreferences::OnClear(wxCommandEvent& ev) {
 }
 
 bool CDlgAdvPreferences::ConfirmClear() {
-	int res = wxGetApp().SafeMessageBox(_("Do you really want to clear all local preferences ?"),
+	int res = wxGetApp().SafeMessageBox(_(
+	    "Do you really want to clear all local preferences?\n(This will not affect exclusive applications.)"),
 		_("Confirmation"),wxCENTER | wxICON_QUESTION | wxYES_NO | wxNO_DEFAULT,this);
 	
 	return res==wxYES;
