@@ -2318,10 +2318,6 @@ int CMainDocument::SetProxyConfiguration() {
     if (!proxy_info.http_user_name.empty() || !proxy_info.http_user_passwd.empty())
         proxy_info.use_http_authentication = true;
 
-    proxy_info.socks_version = 4;
-    if (!proxy_info.socks5_user_name.empty() || !proxy_info.socks5_user_passwd.empty())
-        proxy_info.socks_version = 5;
-
     iRetVal = rpc.set_proxy_settings(proxy_info);
     if (iRetVal) {
         wxLogTrace(wxT("Function Status"), wxT("CMainDocument::SetProxyInfo - Set Proxy Info Failed '%d'"), iRetVal);
@@ -2479,7 +2475,13 @@ wxString result_description(RESULT* result, bool show_resources) {
             strBuffer += _("Ready to start");
         }
         if (result->scheduler_wait) {
-            strBuffer += _(" (Scheduler wait)");
+            if (strlen(result->scheduler_wait_reason)) {
+                strBuffer += _(" (Scheduler wait: ");
+                strBuffer += wxString(result->scheduler_wait_reason, wxConvUTF8);
+                strBuffer += _(")");
+            } else {
+                strBuffer += _(" (Scheduler wait)");
+            }
         }
         if (result->network_wait) {
             strBuffer += _(" (Waiting for network access)");
@@ -2502,15 +2504,24 @@ wxString result_description(RESULT* result, bool show_resources) {
         break;
     case RESULT_ABORTED:
         switch(result->exit_status) {
-        case ERR_ABORTED_VIA_GUI:
+        case EXIT_ABORTED_VIA_GUI:
             strBuffer += _("Aborted by user");
             break;
-        case ERR_ABORTED_BY_PROJECT:
+        case EXIT_ABORTED_BY_PROJECT:
             strBuffer += _("Aborted by project");
             break;
-        case ERR_UNSTARTED_LATE:
+        case EXIT_UNSTARTED_LATE:
             strBuffer += _("Aborted: not started by deadline");
             break;
+        case EXIT_DISK_LIMIT_EXCEEDED:
+            strBuffer += _("Aborted: disk limit exceeded");
+            break;
+        case EXIT_TIME_LIMIT_EXCEEDED:
+            strBuffer += _("Aborted: run time limit exceeded");
+            break;
+        case EXIT_MEM_LIMIT_EXCEEDED:
+            strBuffer += _("Aborted: memory limit exceeded");
+            break;
         default:
             strBuffer += _("Aborted");
         }
