@@ -198,8 +198,8 @@ CViewProjects::CViewProjects(wxNotebook* pNotebook) :
     pGroup->m_Tasks.push_back( pItem );
 
     pItem = new CTaskItem(
-        _("Detach"),
-        _("Detach computer from this project.  Tasks in progress will be lost (use 'Update' first to report any completed tasks)."),
+        _("Remove"),
+        _("Remove this project.  Tasks in progress will be lost (use 'Update' first to report any completed tasks)."),
         ID_TASK_PROJECT_DETACH 
     );
     pGroup->m_Tasks.push_back( pItem );
@@ -256,6 +256,11 @@ const char** CViewProjects::GetViewIcon() {
 }
 
 
+const int CViewProjects::GetViewCurrentViewPage() {
+    return VW_PROJ;
+}
+
+
 wxString CViewProjects::GetKeyValue1(int iRowIndex) {
     CProject*   project;
     
@@ -474,7 +479,7 @@ void CViewProjects::OnProjectDetach( wxCommandEvent& WXUNUSED(event) ) {
     if (!pDoc->IsUserAuthorized())
         return;
 
-    pFrame->UpdateStatusText(_("Detaching from project..."));
+    pFrame->UpdateStatusText(_("Removing project..."));
 
     row = -1;
     while (1) {
@@ -487,13 +492,13 @@ void CViewProjects::OnProjectDetach( wxCommandEvent& WXUNUSED(event) ) {
         }
 
         strMessage.Printf(
-            _("Are you sure you want to detach from project '%s'?"), 
+            _("Are you sure you want to remove project '%s'?"), 
             pProject->m_strProjectName.c_str()
         );
 
         iAnswer = wxGetApp().SafeMessageBox(
             strMessage,
-            _("Detach from Project"),
+            _("Remove Project"),
             wxYES_NO | wxICON_QUESTION,
             this
         );
@@ -537,7 +542,7 @@ void CViewProjects::OnProjectWebsiteClicked( wxEvent& event ) {
     pFrame->UpdateStatusText(_("Launching browser..."));
 
     int website_task_index = event.GetId() - ID_TASK_PROJECT_WEB_PROJDEF_MIN;
-    pFrame->ExecuteBrowserLink(
+    wxLaunchDefaultBrowser(
         m_TaskGroups[1]->m_Tasks[website_task_index]->m_strWebSiteLink
     );
 
@@ -1038,6 +1043,18 @@ wxInt32 CViewProjects::FormatResourceShare(float fBuffer, float fBufferPercent,
     return 0;
 }
 
+wxString rpc_reason_string_translated(int reason) {
+    switch (reason) {
+    case RPC_REASON_USER_REQ: return _("Requested by user");
+    case RPC_REASON_NEED_WORK: return _("To fetch work");
+    case RPC_REASON_RESULTS_DUE: return _("To report completed tasks");
+    case RPC_REASON_TRICKLE_UP: return _("To send trickle-up message");
+    case RPC_REASON_ACCT_MGR_REQ: return _("Requested by account manager");
+    case RPC_REASON_INIT: return _("Project initialization");
+    case RPC_REASON_PROJECT_REQ: return _("Requested by project");
+    default: return _("Unknown reason");
+    }
+}
 
 void CViewProjects::GetDocStatus(wxInt32 item, wxString& strBuffer) const {
     PROJECT* project = NULL;
@@ -1055,14 +1072,16 @@ void CViewProjects::GetDocStatus(wxInt32 item, wxString& strBuffer) const {
             append_to_status(strBuffer, _("Won't get new tasks"));
         }
         if (project->ended) {
-            append_to_status(strBuffer, _("Project ended - OK to detach"));
+            append_to_status(strBuffer, _("Project ended - OK to remove"));
         }
         if (project->detach_when_done) {
-            append_to_status(strBuffer, _("Will detach when tasks done"));
+            append_to_status(strBuffer, _("Will remove when tasks done"));
         }
         if (project->sched_rpc_pending) {
             append_to_status(strBuffer, _("Scheduler request pending"));
-            append_to_status(strBuffer, wxString(rpc_reason_string(project->sched_rpc_pending), wxConvUTF8));
+            append_to_status(strBuffer,
+                rpc_reason_string_translated(project->sched_rpc_pending)
+            );
         }
         if (project->scheduler_rpc_in_progress) {
             append_to_status(strBuffer, _("Scheduler request in progress"));
@@ -1108,7 +1127,7 @@ void CViewProjects::GetDocProjectURL(wxInt32 item, wxString& strBuffer) const {
     }
 
     if (project) {
-        strBuffer = wxString(project->master_url.c_str(), wxConvUTF8);
+        strBuffer = wxString(project->master_url, wxConvUTF8);
     } else {
         strBuffer = wxEmptyString;
     }
