@@ -70,18 +70,27 @@ double next_connect_time = 0.0;
 CC_STATE cc_state;
 CC_STATUS cc_status;
 
-// Possible values of iBrandId:
+#ifdef __APPLE__
+// Possible values of brandId (determined at run time on Mac):
 #define BOINC_BRAND_ID 0
 #define GRIDREPUBLIC_BRAND_ID 1
 #define PROGRESSTHRUPROCESSORS_BRAND_ID 2
 #define CHARITYENGINE_BRAND_ID 3
 
+char* brand_name = "BOINC";
+char* logo_file = "boinc_logo_black.jpg";
+# else
+// These defines are used only on Windows builds
 #ifdef _GRIDREPUBLIC
-static long iBrandId = GRIDREPUBLIC_BRAND_ID;
+const char* brand_name = "GridRepublic";
+const char* logo_file = "gridrepublic_ss_logo.jpg";
 #elif defined(_CHARITYENGINE)
-static long iBrandId = CHARITYENGINE_BRAND_ID;
+const char* brand_name = "Charity Engine";
+const char* logo_file = "CE_ss_logo.jpg";
 #else
-static long iBrandId = BOINC_BRAND_ID;   // Default value for BOINC
+const char* brand_name = "BOINC";
+const char* logo_file = "boinc_logo_black.jpg";
+#endif
 #endif
 
 #if 0
@@ -235,32 +244,19 @@ void show_project(unsigned int index, float alpha) {
 
 void show_disconnected() {
     float x=.3, y=.3;
-    if (iBrandId == GRIDREPUBLIC_BRAND_ID) {
-        txf_render_string(.1, x, y, 0, ALERT_SIZE, white, 0, "GridRepublic is not running.");
-    } else if (iBrandId == CHARITYENGINE_BRAND_ID) {   
-        txf_render_string(.1, x, y, 0, ALERT_SIZE, white, 0, "Charity Engine is not running.");
-    } else {    
-        txf_render_string(.1, x, y, 0, ALERT_SIZE, white, 0, "BOINC is not running.");
-    }
+    char buf[256];
+    sprintf(buf, "%s is not running.", brand_name);
+    txf_render_string(.1, x, y, 0, ALERT_SIZE, white, 0, buf);
 }
 
 void show_no_projects() {
     float x=.2, y=.3;
-    if (iBrandId == GRIDREPUBLIC_BRAND_ID) {
-        txf_render_string(.1, x, y, 0, ALERT_SIZE, white, 0, "GridRepublic is not attached to any projects.");
-    } else if (iBrandId == CHARITYENGINE_BRAND_ID) {   
-        txf_render_string(.1, x, y, 0, ALERT_SIZE, white, 0, "Charity Engine is not attached to any projects.");
-    } else {    
-        txf_render_string(.1, x, y, 0, ALERT_SIZE, white, 0, "BOINC is not attached to any projects.");
-    }
+    char buf[256];
+    sprintf(buf, "%s is not attached to any projects.", brand_name);
+    txf_render_string(.1, x, y, 0, ALERT_SIZE, white, 0, buf);
     y = .25;
-    if (iBrandId == GRIDREPUBLIC_BRAND_ID) {
-        txf_render_string(.1, x, y, 0, ALERT_SIZE, white, 0, "Attach to projects using the GridRepublic Desktop.");
-    } else if (iBrandId == CHARITYENGINE_BRAND_ID) {   
-        txf_render_string(.1, x, y, 0, ALERT_SIZE, white, 0, "Attach to projects using the Charity Engine Desktop.");
-    } else {    
-        txf_render_string(.1, x, y, 0, ALERT_SIZE, white, 0, "Attach to projects using the BOINC Manager.");
-    }
+    sprintf(buf, "Attach to projects using %s.", brand_name);
+    txf_render_string(.1, x, y, 0, ALERT_SIZE, white, 0, buf);
 }
 
 #define MAX_JOBS_DISPLAY   4
@@ -272,6 +268,7 @@ void show_jobs(unsigned int index, double alpha) {
     unsigned int nfound = 0;
     unsigned int i;
     cc_status.task_suspend_reason &= ~SUSPEND_REASON_CPU_THROTTLE;
+    char buf[256];
     
     if (!cc_status.task_suspend_reason) {
         for (i=0; i<cc_state.results.size(); i++) {
@@ -309,13 +306,11 @@ void show_jobs(unsigned int index, double alpha) {
         case SUSPEND_REASON_NO_RECENT_INPUT:
             p = "Computing suspended while computer not in use"; break;
         case SUSPEND_REASON_INITIAL_DELAY:
-            if (iBrandId == GRIDREPUBLIC_BRAND_ID) {
-                p = "Computing suspended while GridRepublic is starting up"; break;
-            } else if (iBrandId == CHARITYENGINE_BRAND_ID) {   
-                p = "Computing suspended while Charity Engine is starting up"; break;
-            } else {    
-                p = "Computing suspended while BOINC is starting up"; break;
-            }
+            sprintf(buf,
+                "Computing suspended while %s is starting up", brand_name
+            );
+            p = buf;
+            break;
         case SUSPEND_REASON_EXCLUSIVE_APP_RUNNING:
             p = "Computing suspended while exclusive application running"; break;
         case SUSPEND_REASON_CPU_USAGE:
@@ -425,8 +420,13 @@ void app_graphics_render(int xs, int ys, double t) {
                 showing_project = false;
                 project_index++;
             } else {
-                job_index += MAX_JOBS_DISPLAY;
-                job_index %= cc_state.results.size();
+                int n = cc_state.results.size();
+                if (n) {
+                    job_index += MAX_JOBS_DISPLAY;
+                    job_index %= n;
+                } else {
+                    job_index = 0;
+                }
                 showing_project = true;
             }
         }
@@ -466,13 +466,7 @@ void app_graphics_init() {
 #ifdef _WCG
     logo.load_image_file("wcg.bmp");
 #else
-    if (iBrandId == GRIDREPUBLIC_BRAND_ID) {
-        logo.load_image_file("gridrepublic_ss_logo.jpg");
-    } else if (iBrandId == CHARITYENGINE_BRAND_ID) {   
-        logo.load_image_file("CE_ss_logo.jpg");
-    } else {    
-        logo.load_image_file("boinc_logo_black.jpg");
-    }
+    logo.load_image_file(logo_file);
 #endif
     init_lights();
 }
@@ -502,13 +496,20 @@ int main(int argc, char** argv) {
     }
     
 #ifdef __APPLE__
-    // For GridRepublic, the installer put a branding file in our data directory
+    long brandId = BOINC_BRAND_ID;
+    // For GridRepublic or CharityEngine, the installer put a branding file in our data directory
     FILE *f = fopen("/Library/Application Support/BOINC Data/Branding", "r");
     if (f) {
-        fscanf(f, "BrandId=%ld\n", &iBrandId);
+        fscanf(f, "BrandId=%ld\n", &brandId);
         fclose(f);
+        if (brandId == GRIDREPUBLIC_BRAND_ID) {
+            brand_name = "GridRepublic";
+            logo_file = "gridrepublic_ss_logo.jpg";
+        } else if (brandId == CHARITYENGINE_BRAND_ID) {
+            brand_name = "Charity Engine";
+            logo_file = "CE_ss_logo.jpg";
+        }
     }
-#else
 #endif
 
     boinc_graphics_loop(argc, argv, "BOINC screensaver");
