@@ -1,4 +1,20 @@
 <?php
+// This file is part of BOINC.
+// http://boinc.berkeley.edu
+// Copyright (C) 2008 University of California
+//
+// BOINC is free software; you can redistribute it and/or modify it
+// under the terms of the GNU Lesser General Public License
+// as published by the Free Software Foundation,
+// either version 3 of the License, or (at your option) any later version.
+//
+// BOINC is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+// See the GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with BOINC.  If not, see <http://www.gnu.org/licenses/>.
 
 require_once("../inc/util.inc");
 require_once("../inc/bossa_db.inc");
@@ -25,7 +41,9 @@ function show_app($app) {
     } else {
         $x = "<a href=bossa_get_job.php?bossa_app_id=$app->id>Get job</a>";
     }
-    row2("$app->name<span class=note><br>$app->description</span>", $x);
+    $est = number_format($app->time_estimate/60., 2);
+    $limit = number_format($app->time_limit/60., 2);
+    row2("$app->name<br><span class=note>$app->description<br>Time: $est min. average, $limit min limit</span>", $x);
 }
 
 function show_apps() {
