@@ -30,7 +30,7 @@ $passwd = post_str("passwd");
 $passwd2 = post_str("passwd2");
 
 if ($passwd != $passwd2) {
-    error_page("New passwords are different");
+    error_page(tra("New passwords are different"));
 }
 
 $config = get_config();
@@ -38,41 +38,35 @@ $min_passwd_length = parse_config($config, "<min_passwd_length>");
 if (!$min_passwd_length) $min_passwd_length = 6;
 
 if (!is_ascii($passwd)) {
-    error_page("Passwords may only include ASCII characters.");
+    error_page(tra("Passwords may only include ASCII characters."));
 }
 
 if (strlen($passwd)<$min_passwd_length) {
-    error_page(
-        "New password is too short:
-        minimum password length is $min_passwd_length characters."
-    );
+    error_page(tra("New password is too short: minimum password length is %1 characters.", $min_passwd_length));
 }
 if ($auth) {
     $user = lookup_user_auth($auth);
     if (!$user) {
-        error_page("Invalid account key");
+        error_page(tra("Invalid account key"));
     }
 } else {
     $user = lookup_user_email_addr($email_addr);
     if (!$user) {
-        error_page("No account with that email address was found");
+        error_page(tra("No account with that email address was found"));
     }
     $passwd_hash = md5($old_passwd.$email_addr);
     if ($user->passwd_hash != $passwd_hash) {
-        error_page("Invalid password");
+        error_page(tra("Invalid password"));
     }
 }
 
-page_head("Change password");
+page_head(tra("Change password"));
 $passwd_hash = md5($passwd.$user->email_addr);
 $result = $user->update("passwd_hash='$passwd_hash'");
 if ($result) {
-    echo "Your password has been changed.";
+    echo tra("Your password has been changed.");
 } else {
-    echo "
-        We can't update your password due to a database problem.
-        Please try again later.
-    ";
+    echo tra("We can't update your password due to a database problem. Please try again later.");
 }
 
 page_tail();
