@@ -31,13 +31,12 @@ require_once("../inc/sandbox.inc");
 //
 function lammps_est() {
     $avg_cpu = 0;
-    $disk_space = 0;
     $test_result = 0;
     $descs = array();
     $pipes = array();
     $options = file("cmd_variables");
     $cmd = "../lmp_linux ".$options[0];
-    echo $cmd;
+    //echo $cmd;
     $p = proc_open("$cmd", $descs, $pipes);
     system("unzip pot.zip");
     while (1) {
@@ -53,8 +52,81 @@ function lammps_est() {
         //echo "sleeping\n";
         sleep(1);
     }
+    $total_steps = get_total_steps("cmd_variables");
+    $disk_space = calc_est_size(
+        "lammps_script", "structure_file", "cmd_variables"
+    );
+    $total_cpu = $total_steps*$avg_cpu;
+    return array($test_result, $total_cpu, $disk_space);
+}
 
-    return array($test_result, $avg_cpu, $disk_space);
+function get_total_steps($cmd_file) {
+    $fd = fopen($cmd_file,"r");
+    if (!$fd) {
+        echo "can not open file $cmd_file\n";
+        exit(-1);
+    }
+    $loopno = 1;
+    $looprun = 1;
+    while (!feof($fd)) {
+        $line = fgets($fd,4096);
+        if (preg_match("/loopnumber\s+\d+/", $line, $matches)
+            && preg_match("/\d+/", $matches[0], $no)
+        ) {
+            $loopno=$no[0];
+        }
+        if (preg_match("/looprun\s+\d+/", $line, $matches)
+            and preg_match("/\d+/", $matches[0], $no)
+        ) {
+            $looprun=$no[0];
+        }
+    }
+    fclose($fd);
+    $total_steps = $loopno*$looprun;
+    print "total_steps = ".$total_steps;
+    return $total_steps;
+}
+
+function calc_est_size($lammps_script, $structure_file, $cmd_file){
+    $dump_types = 0;
+    $fd = fopen($lammps_script,"r");
+    if (!$fd){
+        echo "can not open file $lammps_script\n";
+        exit(-1);
+    }
+    while (!feof($fd)){
+        $line = fgets($fd, 4096);
+        if (preg_match("/^\s*dump/", $line)
+            and preg_match_all("/dump\S+\.\w{3}/", $line, $matches, PREG_PATTERN_ORDER)
+        ) {
+            $dump_types=count($matches[0]);
+            break;
+        }
+    }
+    fclose($fd);
+    print "dump_types= ".$dump_types;
+
+    $structure_file_size = filesize($structure_file);
+    $fd = fopen($cmd_file,"r");
+    if (!$fd){
+        echo "can not open file $cmd_file\n";
+        exit(-1);
+    }
+    print "structure_file_size=".$structure_file_size;
+   
+    $loopno=1;
+    while (!feof($fd)){
+        $line = fgets($fd,4096);
+        if(preg_match("/loopnumber\s+\d+/", $line, $matches)){
+            if(preg_match("/\d+/", $matches[0], $no)){
+                $loopno=$no[0];
+            }
+        }
+    }
+    fclose($fd);
+    print "loopno=".$loopno;
+    $est_size = $loopno*$structure_file_size*0.8*$dump_types;
+    return $est_size;
 }
 
 function calc_step_cpu($filename) {
@@ -87,7 +159,7 @@ function calc_step_cpu($filename) {
             $start_step = $step;
         } else {
             $cur_step = $step;
-            if ($cur_step-$start_step>=5) {
+            if ($cur_step-$start_step>=9) {
                 $avg_cpu = $cpu/($cur_step-$start_step);
                 //echo "avg_cpu is ".$avg_cpu;
                 break;
@@ -114,16 +186,18 @@ function show_submit_form($user) {
         <input type=hidden name=action value=prepare>
     ";
     start_table();
-    row2("Structure file", sandbox_file_select($user, "structure_file"));
-    row2("Script file", sandbox_file_select($user, "command_file"));
-    row2("Command-line file<br><span class=note>List of command lines, one per job</span>", sandbox_file_select($user, "cmdline_file"));
-    row2("Zipped potential files", sandbox_file_select($user, "pot_files"));
-    row2("Area", area_select());
+    row2("<strong>structure_file</strong><br><span class=note>structure_file*</span>", sandbox_file_select($user, "structure_file"));
+    row2("<strong>lammps_script</strong><br><span class=note>lammps_script*</span>", sandbox_file_select($user, "lammps_script"));
+    row2("<strong>cmdline_file</strong><br><span class=note>cmdline_file*</span><span class=note> ( List of command lines, one per job )</span>", sandbox_file_select($user, "cmdline_file"));
+    row2("<strong>pot.zip</strong><br><span class=note>*.zip</span><span class-note> ( Zipped Potential files )</span>", sandbox_file_select($user, "zip"));
+    row2("<strong>Area</strong>", area_select());
     row2("", "<input type=submit value=Prepare>");
     end_table();
     echo "</form>
         <p>
-        <a href=sandbox.php>File sandbox</a>
+        <a href=sandbox.php><strong> File_Sandbox </strong></a>
+        <a href=lammps.php><strong> Job_Submit </strong></a>
+        <a href=submit.php><strong> Job_Control </strong></a>
     ";
     
     page_tail();
@@ -180,9 +254,9 @@ function estimated_makespan($njobs, $flops_per_job) {
 
 function prepare_batch($user) {
     $structure_file_path = get_file_path($user, 'structure_file');
-    $command_file_path = get_file_path($user, 'command_file');
+    $command_file_path = get_file_path($user, 'lammps_script');
     $cmdline_file_path = get_file_path($user, 'cmdline_file');
-    $pot_files_path = get_file_path($user, 'pot_files');
+    $pot_files_path = get_file_path($user, 'zip');
 
     $info = null;
     $info->structure_file_path = $structure_file_path;
@@ -217,8 +291,9 @@ function prepare_batch($user) {
 
     system("rm *");
     $info->rsc_fpops_est = $est_cpu_time * 5e9;
+    $info->rsc_fpops_bound = $info->rsc_fpops_est * 20;
 
-    $info->rsc_disk_bound = 1e8;
+    $info->rsc_disk_bound = $disk;
 
     $tmpfile = tempnam("/tmp", "lammps_");
     file_put_contents($tmpfile, serialize($info));
@@ -228,8 +303,8 @@ function prepare_batch($user) {
     $njobs = count(file($cmdline_file_path));
     $secs_est = estimated_makespan($njobs, $info->rsc_fpops_est);
     $hrs_est = number_format($secs_est/3600, 1);
-    $client_mb = $info->rsc_disk_bound/1e6;
-    $server_mb = $njobs*$client_mb;
+    $client_mb = number_format($info->rsc_disk_bound/1e6, 1);
+    $server_mb = number_format($njobs*$info->rsc_disk_bound/1e6, 1);
 
     page_head("Batch prepared");
     echo "
@@ -247,7 +322,7 @@ function prepare_batch($user) {
 }
 
 function submit_job($app, $batch_id, $info, $cmdline, $i) {
-    $cmd = "cd ../..; ./bin/create_work --appname $app->name --batch $batch_id --rsc_fpops_est $info->rsc_fpops_est";
+    $cmd = "cd ../..; ./bin/create_work --appname $app->name --batch $batch_id --rsc_fpops_est $info->rsc_fpops_est --rsc_fpops_bound $info->rsc_fpops_bound";
     if ($cmdline) {
         $cmd .= " --command_line \"$cmdline\"";
     }
@@ -255,11 +330,13 @@ function submit_job($app, $batch_id, $info, $cmdline, $i) {
     $cmd .= " ".basename($info->structure_file_path);
     $cmd .= " ".basename($info->command_file_path);
     $cmd .= " ".basename($info->pot_files_path);
-    echo "<br> $cmd\n"; 
+    //echo "<br> $cmd\n"; 
 
     $ret = system($cmd);
     if ($ret === FALSE) {
         error_page("can't create job");
+    } else {
+        header('Location: submit.php');
     }
 }
 
@@ -268,21 +345,28 @@ function submit_batch($user, $app) {
     $x = file_get_contents("$tmpfile");
     $info = unserialize($x);
 
+    $njobs=0;
     $cmdlines = file($info->cmdline_file_path);
-    $njobs = count($cmdlines);
-
+    foreach ($cmdlines as $cmdline){
+        if (preg_match("/^\s*-var/", $cmdline)) {
+            $njobs++;
+        }
+    }
+    
     $now = time();
-    $batch_name = $info->area;
+    $batch_name = $info->area."_".date("Y-M-d D H:i:s");
 
     $batch_id = BoincBatch::insert(
-        "(user_id, create_time, njobs, name, app_id) values ($user->id, $now, $njobs, '$batch_name', $app->id)"
+        "(user_id, create_time, njobs, name, app_id, state) values ($user->id, $now, $njobs, '$batch_name', $app->id, ".BATCH_STATE_IN_PROGRESS.")"
     );
 //    $batch_id=99;
 
     $i = 0;
     foreach ($cmdlines as $cmdline) {
-        submit_job($app, $batch_id, $info, $cmdline, $i);
-        $i++;
+        if (preg_match("/^\s*-var/", $cmdline)){
+            submit_job($app, $batch_id, $info, $cmdline, $i);
+            $i++;
+        }
     }
 }
 
