@@ -50,7 +50,7 @@ If you do not respond within 60 days, ".$user->name." will
 be allowed to become the team founder.
 ";
 
-    pm_send($founder, $subject, $body, false);
+    pm_send($user, $founder, $subject, $body, false);
 
     $subject = PROJECT." team founder transfer";
     $body = "Team member ".$user->name." has asked that you
@@ -138,6 +138,6 @@ echo "<a href='team_display.php?teamid=$team->id'>".tra("Return to team page")."
 
 page_tail();
 
-$cvs_version_tracker[]="\$Id: team_founder_transfer_action.php 23010 2011-02-09 22:11:34Z davea $";  //Generated automatically - do not edit
+$cvs_version_tracker[]="\$Id: team_founder_transfer_action.php 23941 2011-08-06 07:11:17Z davea $";  //Generated automatically - do not edit
 
 ?>
