@@ -19,7 +19,6 @@
 #include "boinc_win.h"
 #else
 #include "config.h"
-#include <cassert>
 #include <cstring>
 #include <string>
 #endif
@@ -71,8 +70,6 @@ MSG_LOG::MSG_LOG(FILE* output_) {
 }
 
 void MSG_LOG::enter_level(int diff) {
-    assert (indent_level >= 0);
-
     if (indent_level <= 0 ) indent_level = 0;
     if ((indent_level + diff) <= 0) return;
     if (indent_level >= 39 ) indent_level = 39;
@@ -81,8 +78,6 @@ void MSG_LOG::enter_level(int diff) {
     spaces[indent_level] = ' ';
     indent_level += diff*2;
     spaces[indent_level] = 0;
-
-    assert (indent_level >= 0);
 }
 
 void MSG_LOG::vprintf(int kind, const char* format, va_list va) {
