@@ -20,7 +20,7 @@
 
 #include "config.h"
 
-#ifdef HAVE_PROCFS_H
+#if HAVE_PROCFS_H
 // Can't use large file calls with solaris procfs.
 #if defined(_FILE_OFFSET_BITS) && ( _FILE_OFFSET_BITS == 64 )
 #undef _FILE_OFFSET_BITS
@@ -38,11 +38,11 @@
 #include <dirent.h>
 #include <signal.h>
 
-#ifdef HAVE_UNISTD_H
+#if HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 
-#ifdef HAVE_PROCFS_H
+#if HAVE_PROCFS_H
 #include <procfs.h>  // definitions for solaris /proc structs
 #endif
 
@@ -164,7 +164,7 @@ int PROC_STAT::parse(char* buf) {
 //
 int procinfo_setup(PROC_MAP& pm) {
 
-#ifdef HAVE_DIRENT_H
+#if HAVE_DIRENT_H
     DIR *dir;
     dirent *piddir;
     FILE* fd;
@@ -188,7 +188,7 @@ int procinfo_setup(PROC_MAP& pm) {
         sprintf(pidpath, "/proc/%s/psinfo", piddir->d_name);
         fd = fopen(pidpath, "r");
         if (fd) {
-            memset(&p, 0, sizeof(p));
+            p.clear();
             if (fread(&psinfo, sizeof(psinfo_t), 1, fd) == 1) {
                 p.id = psinfo.pr_pid;
                 p.parentid = psinfo.pr_ppid;
@@ -225,7 +225,7 @@ int procinfo_setup(PROC_MAP& pm) {
             if (retval) {
                 final_retval = retval;
             } else {
-                memset(&p, 0, sizeof(p));
+                p.clear();
                 p.id = ps.pid;
                 p.parentid = ps.ppid;
                 p.swap_size = ps.vsize;
