@@ -22,7 +22,7 @@
 
 #ifndef _WIN32
 #include <sys/types.h>
-#ifdef HAVE_SYS_SHM_H
+#if HAVE_SYS_SHM_H
 #include <sys/shm.h>
 #endif
 #endif
