@@ -1,16 +1,12 @@
 #!/usr/bin/env python
-
-# $Id: projectxml.py 4772 2004-12-06 22:41:19Z boincadm $
-
+# $Id: projectxml.py 15679 2008-07-25 22:13:41Z davea $
 # projectxml.py - module to read and parse project.xml
 
 '''
 SYNOPSIS:  parses and writes project.xml
-
 USAGE:     from Boinc import projectxml
            project = projectxml.ProjectFile().read()
            project.commit_all()
-
 '''
 
 import sys
@@ -31,6 +27,7 @@ class ProjectFile(XMLConfig):
         default_project_file = self
     def _get_elements(self):
         self.xml_boinc   = get_element(self.xml, 'boinc', optional=False)
+	self.elements 	 = ConfigDictList(self.xml_boinc)
         self.add_objects_and_args = []
         for node in self.xml_boinc.childNodes:
             add_object = add_objects.get(node.nodeName)
@@ -38,7 +35,7 @@ class ProjectFile(XMLConfig):
                 raise SystemExit("Error in %s: No such object '%s' to add." %(self.filename,node.nodeName))
             self.add_objects_and_args.append((add_object, get_elements_as_dict(node)))
     def _set_elements(self):
-        assert(0)                       # TODO (maybe)
+	self.elements.save()
     def commit_all(self):
         '''Commits all new data to the BOINC project database.'''
         for add_object, untranslated_args_dict in self.add_objects_and_args:
@@ -46,7 +43,6 @@ class ProjectFile(XMLConfig):
                 do_add_object(add_object, untranslated_args_dict, skip_old=True)
             except AddObjectException, e:
                 raise SystemExit('Error in %s: %s' %(self.filename,e))
-
     default_xml = '<boinc></boinc>'
 
 def default_project():
