@@ -85,6 +85,7 @@ struct TASK {
     bool multi_process;
 
     // dynamic stuff follows
+    double current_cpu_time;
     double final_cpu_time;
     double starting_cpu;
         // how much CPU time was used by tasks before this in the job file
@@ -206,6 +207,7 @@ int TASK::parse(XML_PARSER& xp) {
     char buf[8192];
 
     weight = 1;
+    current_cpu_time = 0;
     final_cpu_time = 0;
     stat_first = true;
     pid = 0;
@@ -572,6 +574,9 @@ bool TASK::poll(int& status) {
         if (exit_code != STILL_ACTIVE) {
             status = exit_code;
             final_cpu_time = cpu_time();
+            if (final_cpu_time < current_cpu_time) {
+                final_cpu_time = current_cpu_time;
+            }
             return true;
         }
     }
@@ -581,7 +586,11 @@ bool TASK::poll(int& status) {
 
     wpid = wait4(pid, &status, WNOHANG, &ru);
     if (wpid) {
+        getrusage(RUSAGE_CHILDREN, &ru);
         final_cpu_time = (float)ru.ru_utime.tv_sec + ((float)ru.ru_utime.tv_usec)/1e+6;
+        if (final_cpu_time < current_cpu_time) {
+            final_cpu_time = current_cpu_time;
+        }
         return true;
     }
 #endif
@@ -618,7 +627,8 @@ void TASK::resume() {
 }
 
 double TASK::cpu_time() {
-    return process_tree_cpu_time(pid);
+    current_cpu_time = process_tree_cpu_time(pid);
+    return current_cpu_time;
 }
 
 void poll_boinc_messages(TASK& task) {
