@@ -15,4 +15,4 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with BOINC.  If not, see <http://www.gnu.org/licenses/>.
 
-extern bool resend_lost_work(SCHEDULER_REQUEST&, SCHEDULER_REPLY&);
+extern bool resend_lost_work();
