@@ -669,11 +669,7 @@ static inline int check_deadline(
     } else {
         double ewd = estimate_duration(wu, bav);
         if (hard_app(app)) ewd *= 1.3;
-        double est_completion_delay = get_estimated_delay(bav) + ewd;
-        double est_report_delay = std::max(
-            est_completion_delay,
-            g_request->global_prefs.work_buf_min()
-        );
+        double est_report_delay = get_estimated_delay(bav) + ewd;
         double diff = est_report_delay - wu.delay_bound;
         if (diff > 0) {
             if (config.debug_send) {
@@ -727,7 +723,8 @@ int wu_is_infeasible_fast(
     }
 
     // homogeneous redundancy: can't send if app uses HR and
-    // 1) host is of unknown HR class
+    // 1) host is of unknown HR class, or
+    // 2) WU is already committed to different HR class
     //
     if (app_hr_type(app)) {
         if (hr_unknown_class(g_reply->host, app_hr_type(app))) {
@@ -750,6 +747,21 @@ int wu_is_infeasible_fast(
         }
     }
 
+    // homogeneous app version
+    //
+    if (app.homogeneous_app_version) {
+        int avid = wu.app_version_id;
+        if (avid && bav.avp->id != avid) {
+            if (config.debug_send) {
+                log_messages.printf(MSG_NORMAL,
+                    "[send] [HOST#%d] [WU#%d %s] failed homogeneous app version check: %d %d\n",
+                    g_reply->host.id, wu.id, wu.name, avid, bav.avp->id
+                );
+            }
+            return INFEASIBLE_HAV;
+        }
+    }
+
     if (config.one_result_per_user_per_wu || config.one_result_per_host_per_wu) {
         if (wu_already_in_reply(wu)) {
             return INFEASIBLE_DUP;
@@ -1917,4 +1929,4 @@ done:
     send_user_messages();
 }
 
-const char *BOINC_RCSID_32dcd335e7 = "$Id: sched_send.cpp 25183 2012-02-02 00:18:42Z davea $";
+const char *BOINC_RCSID_32dcd335e7 = "$Id: sched_send.cpp 25567 2012-04-16 20:36:28Z romw $";
