@@ -15,9 +15,8 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with BOINC.  If not, see <http://www.gnu.org/licenses/>.
 
-#include <stdio.h>
-#include "server_types.h"
+#include <cstdio>
 
 extern void handle_time_stats_log(FILE* fin);
-extern void write_time_stats_log(SCHEDULER_REPLY& reply);
-extern bool have_time_stats_log(SCHEDULER_REPLY& reply);
+extern void write_time_stats_log();
+extern bool have_time_stats_log();
