@@ -17,7 +17,9 @@ int zip_main(int argc, char** argv);
 #ifdef _WIN32
 #include <windows.h>
 #else
+#ifndef __APPLE_CC__
 #include "config.h"
+#endif
 #include <string>
 #include <string.h>
 using std::string;
@@ -99,8 +101,8 @@ int boinc_zip(int bZipType, const std::string szFileZip,
         carg = 3 + nVecSize;
 
         // make a dynamic array
-        av = (char**) calloc(carg, sizeof(char*));
-        for (i=0;i<carg;i++)
+        av = (char**) calloc(carg+1, sizeof(char*));
+        for (i=0;i<(carg+1);i++)
                 av[i] = (char*) calloc(_MAX_PATH,sizeof(char));
 
         // just form an argc/argv to spoof the "main"
@@ -133,7 +135,7 @@ int boinc_zip(int bZipType, const std::string szFileZip,
                 if (carg == 4)
                         sprintf(av[3], "-d%s", pvectszFileIn->at(0).c_str());
         }
-        // strcpy(av[carg-1], "");  // null arg
+        strcpy(av[carg], "");  // null arg
         // printf("args: %s %s %s %s\n", av[0], av[1], av[2], av[3]);
 
         if (bZipType == ZIP_IT)
@@ -331,5 +333,5 @@ boinc_UnzipToMemory ( char *zip, char *file, string &retstr )
 } // boinc_UnzipToMemory()
 
 
-const char *BOINC_RCSID_bdf38b2dfb = "$Id: boinc_zip.cpp 16445 2008-11-07 04:13:08Z davea $";
+const char *BOINC_RCSID_bdf38b2dfb = "$Id: boinc_zip.cpp 18195 2009-05-22 21:19:44Z davea $";
 
