@@ -32,7 +32,7 @@
 #ifdef SCO_XENIX
 #  define SYSNDIR
 #else  /* SCO Unix, AIX, DNIX, TI SysV, Coherent 4.x, ... */
-#  if defined(__convexc__) || defined(SYSV) || defined(CRAY) || defined(BSD4_4)
+#  if defined(__convexc__) || defined(SYSV) || defined(CRAY) || defined(BSD4_4) || defined(__HAIKU__)
 #    define DIRENT
 #  endif
 #endif
@@ -1527,4 +1527,4 @@ static void qlfix(__G__ ef_ptr, ef_len)
 
 #endif
 
-const char *BOINC_RCSID_a72f75a0d4 = "$Id: unix.c 9078 2005-12-16 03:45:01Z korpela $";
+const char *BOINC_RCSID_a72f75a0d4 = "$Id: unix.c 18213 2009-05-27 23:36:55Z davea $";
